define('downloadstorelist', ['app', 'base'], function (app, base) {
    'use strict';
    app.controller('downloadStoreListCtrl', ['$scope', '$http', '$interval', '$filter', function ($scope, $http, $interval, $filter) {

        const electron = nodeRequire('electron');
        const { remote, ipcRenderer, shell } = electron;

        //获取基础配置
        const { baseConfig, haveDownLoadStore } = remote.getGlobal('globalObject');

        //获取缓存的手机号码
        $scope.phone = localStorage.getItem(baseConfig.LOCALSTORAGE.PHONE);
        // 初始化当前页码
        $scope.pageNow = 1;
        // 页面下拉选
        $scope.pageSizes = [{
            type: 10,
            title: '10'
        }, {
            type: 20,
            title: '20'
        }, {
            type: 50,
            title: '50'
        }, {
            type: 100,
            title: '100'
        }]
        $scope.pageSize = 10;

        /**
         * @see 常量快定义
         */
        const constant = {
            'sql': {
                'select': {
                    'download': {
                        'list': `select sid,pnumbers,snumbers,sname,status,sprocess,fileSize,fileNumberDown,fileNumber from download where status != 3 and uid = ? `,
                        'total': `select count(*) totalCount from download where uid = ? and status != 3`
                    }
                },
                'update': {
                    'download': {
                        'pause': `update download set status = ? where status != 1 and  uid = ? and sid `
                    }
                },
                'delete': {
                    'download': `delete from download where status != 1 and uid = ? and sid `
                }
            },
            'common': {
                'uid': localStorage.getItem(baseConfig.LOCALSTORAGE.UID),
                'cookieid': localStorage.getItem(baseConfig.LOCALSTORAGE.COOKIEID),
                'prefix': `${baseConfig.HTTP.HTTPSFIX}${baseConfig.SERVER.HOST}${baseConfig.API.FIX}`,
                'suffix': `${baseConfig.SERVER.FIX}?apiKey=${baseConfig.API.APIKEY}`,
                'email': localStorage.getItem(baseConfig.LOCALSTORAGE.EMAIL)
            },
            'url': {
                'downloading': `clientdownload/downloading`,
                'opreation': `clientdownload/downLoadTaskOption`
            }
        }

        /**
         * @see 系统退出登录
         */
        $scope.logout = function () {
            base.logout();
        }

        $scope.allCheck = false;
        // 全选 全不选
        $scope.checkAll = function () {
            $scope.allCheck = !$scope.allCheck;
            for (var i = 0, j = $scope.downLoadList.length; i < j; i++) {
                if ($scope.downLoadList[i][4] !== 3)
                    $scope.downLoadList[i].checked = $scope.allCheck;
            }
        };

        /**
         * @see 单选与不选
         */
        $scope.boxChecked = function (download) {
            $scope.checked = !$scope.checked;
            download.checked = $scope.checked;
        }

        /**
		 * @see 相关操作
		 * @param from 操作来源
		 */
        $scope.operation = function (from) {
            if (from === 'view')
                viewDownLoadFile();
            else if (from === 'pause') {//暂停所选数据
                $scope.operationDataList = [];
                for (var i = 0, j = $scope.downLoadList.length; i < j; i++) {
                    if ($scope.downLoadList[i].checked)
                        $scope.operationDataList.push($scope.downLoadList[i]);
                }

                if ($scope.operationDataList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    var result = base.confirm('此操作具有风险性，您确认暂停么?', (result) => {
                        if (result)
                            operationDownLoadData(from, $scope.operationDataList);
                    });
                }
            } else if (from === 'delete') {//删除所选数据
                $scope.operationDataList = [];
                for (var i = 0, j = $scope.downLoadList.length; i < j; i++) {
                    if ($scope.downLoadList[i].checked)
                        $scope.operationDataList.push($scope.downLoadList[i]);
                }

                if ($scope.operationDataList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    var result = base.confirm('', (result) => {
                        if (result)
                            operationDownLoadData(from, $scope.operationDataList);
                    });
                }
            } else if (from === 'pauseall') {//暂停全部
                if ($scope.nolist !== '') {
                    base.msgModal('暂时无可以暂停的数据');
                } else {
                    var result = base.confirm('此操作具有风险性，您确认暂停么?', (result) => {
                        if (result)
                            operationDownLoadData(from);
                        //getDataList(from, 'all');
                    });
                }
            } else if (from === 'deleteall') {//删除全部
                if ($scope.nolist !== '') {
                    base.msgModal('暂时无可以删除的数据');
                } else {
                    var result = base.confirm('', (result) => {
                        if (result)
                            operationDownLoadData(from);
                        //getDataList(from, 'all');
                    });
                }
            } else if (from === 'start') {//开始选中门店
                $scope.operationDataList = [];
                for (var i = 0, j = $scope.downLoadList.length; i < j; i++) {
                    if ($scope.downLoadList[i].checked)
                        $scope.operationDataList.push($scope.downLoadList[i]);
                }

                if ($scope.operationDataList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    operationDownLoadData(from, $scope.operationDataList);
                }
            } else if (from === 'startall') {//开始全部门店
                if ($scope.nolist !== '') {
                    base.msgModal('暂时无可以开始的数据');
                } else {
                    operationDownLoadData(from);
                    //getDataList(from, 'all');
                }
            } else if (from === 'openDownLodDir') {
                openDownLodDir();
            }
        }

        /**
          * @see 点击打开下载目录
          */
        var openDownLodDir = function () {
            shell.openItem($scope.downloadDir);
        };

        var viewDownLoadFile = function () {
            let dirName = __dirname;
            dirName = dirName.substring(0, dirName.indexOf('template') + 8);
            location.href = `file://../${dirName}/file/downloadfilelist.html`;
        }


        /**
         * @see 对下载列表数据的各种操作
         * @param from  方法调用来源
         * @param dataList 需要处理的数据
         */
        var operationDownLoadData = function (from, dataList) {
            const idArr = [], dataObj = {};
            if (dataList && dataList.length !== 0) {
                for (var download in dataList) {
                    idArr.push(dataList[download][0]);
                }
            }


            dataObj.uid = constant.common.uid;
            dataObj.cookieid = constant.common.cookieid;
            if (from === 'pause' || from === 'delete' || from === 'start')
                dataObj.id = idArr;

            if (from === 'pause' || from === 'pauseall')
                dataObj.op = '0';
            else if (from === 'start' || from === 'startall')
                dataObj.op = '1';
            else if (from === 'delete' || from === 'deleteall')
                dataObj.op = '3';


            $http.post(`${constant.common.prefix}${constant.url.opreation}${constant.common.suffix}`, dataObj, {
                'headers': baseConfig.HEADERS.ANGULAR
            }).success(function (data) {
                let { backdata } = data, { status } = backdata;
                if (status === 0) {
                    if ((from === 'start' || from === 'startall') && !haveDownLoadStore) {
                        const sendObj = {
                            'uid': constant.common.uid,
                            'cookieid': constant.common.cookieid,
                            'email': constant.common.email,
                            'op': 'only'
                        };
                        ipcRenderer.send('fileDownLoad', sendObj);
                        ipcRenderer.on('fileDownLoadMessage', (event, val) => {
                            if (val === 'only')
                                getListFromServer('refresh');
                        });
                    } else {
                        base.msgModal('操作成功', location.href);
                    }
                }
            }).error(function () {
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
            });

            // if (idArr.length !== 0) {
            // let sidStr = `(${sidArr.join()})`;
            // if (from === 'pause' || from === 'pauseall')
            //     updateDownloadData(sidStr);
            // else if (from === 'delete' || from === 'deleteall')
            //     deleteDownloadData(sidStr);
            // else if (from === 'start' || from === 'startall')
            //     startDownloadData(sidStr);
            // }
        }

        /**
         * @see 更新下载数据状态
         * @param sidStr 需要更新的门店id字符串
         */
        var updateDownloadData = function (sidStr) {
            if (sidStr) {
                let updateSql = `${constant.sql.update.download.pause} in ${sidStr}`;
                db.transaction(function (t) {
                    t.executeSql(updateSql, [2, constant.common.uid], function (t, r) {
                        getList('main');
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`pause sid download error , and code is -->${code} and message is -->${message}`);
                    });
                });
            }
        }

        /**
         * @see 删除下载数据
         * @param sidStr 需要更新的门店id字符串
         */
        var deleteDownloadData = function (sidStr) {
            if (sidStr) {
                let updateSql = `${constant.sql.delete.download} in ${sidStr}`;
                db.transaction(function (t) {
                    t.executeSql(updateSql, [constant.common.uid], function (t, r) {
                        getList('main');
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`delete sid download error , and code is -->${code} and message is -->${message}`);
                    });
                });
            }
        }

        /**
         * @see 更新下载数据状态
         * @param sidStr 需要更新的门店id字符串
         */
        var startDownloadData = function (sidStr) {
            if (sidStr) {
                let updateSql = `${constant.sql.update.download.pause} in ${sidStr}`;
                db.transaction(function (t) {
                    t.executeSql(updateSql, [0, constant.common.uid], function (t, r) {
                        getList('main');
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`start sid download error , and code is -->${code} and message is -->${message}`);
                    });
                });
            }
        }


        /**
         * @see 获取需要下载的门店数据
         * @param from 方法调用来源
         */
        var getList = function (from) {
            getTotalCountByCondition(from);
        }


        /**
         * @see 获取符合条件的数据的个数
         * @param from 方法调用来源
         */
        var getTotalCountByCondition = function (from) {
            if (from === 'main') {
                db.readTransaction(function (t) {
                    t.executeSql(constant.sql.select.download.total, [constant.common.uid], function (t, r) {
                        let totalCount = r.rows[0].totalCount;
                        getDataList(totalCount, from);
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`code is -->${code} and message is -->${message}`);
                    });
                });
            }
        }


        /**
         * @see 分页获取符合条件的数据列表
         * @param totalCount 符合数据的总条数 || 方法调用来源
         * @param from 方法调用来源
         */
        var getDataList = function (totalCount, from) {
            const downloadList = [];
            db.readTransaction(function (t) {
                let sql = `${constant.sql.select.download.list}`;
                const paramArr = [];
                paramArr.push(constant.common.uid);
                if (from === 'main') {
                    sql = `${sql} limit ?,?`;
                    paramArr.push(($scope.pageNow - 1) * $scope.pageSize, $scope.pageSize);
                }
                t.executeSql(sql, paramArr, function (t, r) {
                    for (var i = 0; i < r.rows.length; i++) {
                        downloadList.splice(i, 0, r.rows[i]);
                    }
                    if (from === 'main') {
                        $scope.downloadList = downloadList;
                        $scope.totalCount = totalCount;
                        if ($scope.totalCount === 0)
                            $scope.nolist = '暂无数据';
                        else
                            $scope.nolist = '';

                        $scope.$apply();
                    } else if (from === 'all') {
                        operationDownLoadData(totalCount, downloadList);
                    }
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`code is -->${code} and message is -->${message}`);
                });
            });
        }

     
        /**
         * @see 从服务器获取正在下载列表
         * @param from 方法调用来源
         */
        var getListFromServer = function (from) {
            $http.post(`${constant.common.prefix}${constant.url.downloading}${constant.common.suffix}`, {
                'uid': constant.common.uid,
                'cookieid': constant.common.cookieid,
                'pageSize': $scope.pageSize,
                'pageNow': $scope.pageNow
            }, {
                    'headers': baseConfig.HEADERS.ANGULAR
                }).success(function (data) {
                    let { backdata } = data, { status } = backdata;
                    if (status === 0) {
                        let { downLoadList, totalCount } = backdata;
                        $scope.downLoadList = downLoadList;
                        console.info(JSON.stringify($scope.downLoadList));
                        $scope.totalCount = totalCount;
                        if ($scope.totalCount === 0)
                            $scope.nolist = '暂无数据';
                        else
                            $scope.nolist = '';
                    } else {
                        base.msgModal('请求过于频繁，请稍后再试 ^_^');
                        $scope.nolist = '暂无数据';
                    }

                    if (from === 'refresh')
                        base.msgModal('开启成功，门店已经已经加入下载队列.');
                    else if (from === 'process')
                        $scope.closeModal();

                }).error(function () {
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                    $scope.nolist = '暂无数据';
                });
        }


        /**
         * @see 点击翻页查询数据
	     */
        $scope.pageChange = function () {
            //getList('main');
            getListFromServer('main');
        }

        /**
         * @see 关闭弹出框
         */
        $scope.closeModal = function () {
            $scope.modalActive = false;
            $scope.loadModal = false;
        }

        /**
         * @since 重启应用
         */
        $scope.restart = function () {
            ipcRenderer.send('restart')
        }

        $scope.$watch('$viewContentLoaded', function () {
            setTimeout(function () {
                ipcRenderer.send('getDownLoadDir');
                ipcRenderer.on('setDownLoadDir', (event, val) => {
                    $scope.downloadDir = val;
                    getListFromServer('main');
                });
            }, 500);
        });


        /**
         * @see ngrepeat 加载完成0.5s之后调用
         */
        $scope.$on('ngRepeatFinished', function () {
            //计时器5s刷新一下进度 
            if ($scope.downLoadList && $scope.downLoadList.length > 0) {
                $interval(() => {
                    getListFromServer('process');
                }, 5000);// 表示每5秒执行一次 
            }
        });

    }]).directive('onRenderFinish', function ($timeout) {// 监听加载状态
        return {
            restrict: 'AC',
            link: function (scope, element, attr) {
                if (scope.$last === true) {
                    scope.$emit('ngRepeatFinished');
                }
            }
        }
    });
});
