define('finishedstorelist', ['app', 'base'], function (app, base) {
    'use strict';
    app.controller('finishedStoreListCtrl', ['$scope', '$http', function ($scope, $http) {

        const electron = nodeRequire('electron');
        const { remote, ipcRenderer, shell } = electron;

        //获取基础配置
        const { baseConfig } = remote.getGlobal('globalObject');
        //获取缓存的手机号码
        $scope.phone = localStorage.getItem(baseConfig.LOCALSTORAGE.PHONE);
        // 初始化当前页码
        $scope.pageNow = 1;
        // 页面下拉选
        $scope.pageSizes = [{
            type: 10,
            title: '10'
        }, {
            type: 20,
            title: '20'
        }, {
            type: 50,
            title: '50'
        }, {
            type: 100,
            title: '100'
        }]
        $scope.pageSize = 10;

        /**
         * @see 常量快定义
         */
        const constant = {
            'sql': {
                'select': {
                    'download': {
                        'list': `select sid,pnumbers,snumbers,sname,status,sprocess,fileSize,fileNumberDown,fileNumber from download where status = 3 and  uid = ? limit ?,?`,
                        'total': `select count(*) totalCount from download where uid = ? and status = 3`
                    }
                },
                'delete': {
                    'download': {
                        'clear': `delete from download where uid = ?  and status = ? `
                    }
                }
            },
            'common': {
                'uid': localStorage.getItem(baseConfig.LOCALSTORAGE.UID),
                'cookieid': localStorage.getItem(baseConfig.LOCALSTORAGE.COOKIEID),
                'prefix': `${baseConfig.HTTP.HTTPSFIX}${baseConfig.SERVER.HOST}${baseConfig.API.FIX}`,
                'suffix': `${baseConfig.SERVER.FIX}?apiKey=${baseConfig.API.APIKEY}`
            },
            'url': {
                'downloaded': `clientdownload/downloaded`,
                'opreation': `clientdownload/downLoadTaskOption`
            }
        }

        /**
         * @see 系统退出登录
         */
        $scope.logout = function () {
            base.logout();
        }

        // 全选 全不选
        $scope.allCheck = false;
        $scope.checkAll = function () {
            $scope.allCheck = !$scope.allCheck;
            for (var i = 0, j = $scope.downLoadList.length; i < j; i++) {
                $scope.downLoadList[i].checked = $scope.allCheck;
            }
        };

        /**
         * @see 单选与不选
         */
        $scope.boxChecked = function (download) {
            $scope.checked = !$scope.checked;
            download.checked = $scope.checked;
        }

        /**
		 * @see 相关操作
		 * @param from 操作来源
		 */
        $scope.operation = function (from) {
            if (from === 'view')
                viewFinishedFile();
            else if (from === 'clear') {//清除数据
                //需要清楚的下载的门店的数据
                $scope.clearStoreList = [];
                for (var i = 0; i < $scope.downLoadList.length; i++) {
                    if ($scope.downLoadList[i].checked)
                        $scope.clearStoreList.push($scope.downLoadList[i]);
                }

                if ($scope.clearStoreList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    var result = base.confirm('', (result) => {
                        if (result)
                            operationDownLoadData(from);
                    });
                }
            } else if (from === 'clearAll') {//清空全部下载数据
                if ($scope.nolist !== '') {
                    base.msgModal('暂无需要清楚的数据');
                } else {
                    var result = base.confirm('', (result) => {
                        if (result)
                            operationDownLoadData(from);
                    });
                }
            } else if (from === 'openDownLodDir') {
                openDownLodDir();
            }
        }


        /**
         * @see 点击打开下载目录
         */
        var openDownLodDir = function () {
            shell.openItem($scope.downloadDir);
        };


        var viewFinishedFile = function () {
            let dirName = __dirname;
            dirName = dirName.substring(0, dirName.indexOf('template') + 8);
            location.href = `file://../${dirName}/file/finishedfilelist.html`;
        }


        /**
        * @see 获取需要下载的门店数据
        * @param from 方法调用来源
        */
        var getList = function (from) {
            getTotalCountByCondition();
        }


        /**
         * @see 获取符合条件的数据的个数
         */
        var getTotalCountByCondition = function () {
            db.readTransaction(function (t) {
                t.executeSql(constant.sql.select.download.total, [constant.common.uid], function (t, r) {
                    let totalCount = r.rows[0].totalCount;
                    getDataList(totalCount);
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`code is -->${code} and message is -->${message}`);
                });
            });
        }

        /**
         * @see 分页获取符合条件的数据列表
         * @param totalCount 符合数据的总条数
         */
        var getDataList = function (totalCount) {
            const downloadList = [];
            db.readTransaction(function (t) {
                t.executeSql(constant.sql.select.download.list, [constant.common.uid, ($scope.pageNow - 1) * $scope.pageSize, $scope.pageSize], function (t, r) {
                    for (var i = 0; i < r.rows.length; i++) {
                        downloadList.splice(i, 0, r.rows[i]);
                    }
                    $scope.downloadList = downloadList;
                    $scope.totalCount = totalCount;
                    if ($scope.totalCount === 0)
                        $scope.nolist = '暂无数据';
                    else
                        $scope.nolist = '';

                    $scope.$apply();

                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`code is -->${code} and message is -->${message}`);
                });
            });
        }

        /**
         * @see 点击翻页查询数据
	     */
        $scope.pageChange = function () {
            getList('mian');
        }


        /**
         * @see 下载数据的相关操作
         * @param from 方法调用来源
         */
        var operationDownLoadData = function (from) {
            const idArr = [], dataObj = {};
            if ($scope.clearStoreList && $scope.clearStoreList.length !== 0) {
                for (var download in $scope.clearStoreList) {
                    idArr.push($scope.clearStoreList[download][0]);
                }
            }


            dataObj.uid = constant.common.uid;
            dataObj.cookieid = constant.common.cookieid;
            dataObj.op = '2';
            if (from === 'clear')
                dataObj.id = idArr;

            $http.post(`${constant.common.prefix}${constant.url.opreation}${constant.common.suffix}`, dataObj, {
                'headers': baseConfig.HEADERS.ANGULAR
            }).success(function (data) {
                let { backdata } = data, { status } = backdata;
                if (status === 0)
                    base.msgModal('操作成功', location.href);
            }).error(function () {
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
            });
            // let operationSql = '';
            // if (from && (from === 'clear' || from === 'clearAll'))
            //     operationSql = `${constant.sql.delete.download.clear}`;

            // if (from === 'clear') {
            //     let sidStr = `(${$scope.clearStoreList.join()})`;
            //     operationSql = `${operationSql} and sid in ${sidStr}`;
            // }

            // if (from === 'update')
            //     operationSql = `update download set status = 3 where uid = '${constant.common.uid}' and pid = '36dcefb457a89c420157a8f753b80009' and sid in ('2402','2403')`;

            // if (operationSql)
            //     clearDownLoadData(operationSql);
        }


        /**
         * @see 清空数据
         * @param  operationSql 清空数据的sql
         */
        var clearDownLoadData = function (operationSql) {
            db.transaction(function (t) {
                t.executeSql(operationSql, [constant.common.uid, 3], function (t, r) {
                    console.dir(r);
                    if (r.rowsAffected !== 0)
                        getList('mian');
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`code is -->${code} and message is -->${message}`);
                });
            });
        }


        /**
         * @see 从服务器获取正在下载列表
         * @param from 方法调用来源
         */
        var getListFromServer = function (from) {
            $http.post(`${constant.common.prefix}${constant.url.downloaded}${constant.common.suffix}`, {
                'uid': constant.common.uid,
                'cookieid': constant.common.cookieid,
                'pageSize': $scope.pageSize,
                'pageNow': $scope.pageNow
            }, {
                    'headers': baseConfig.HEADERS.ANGULAR
                }).success(function (data) {
                    let { backdata } = data, { status } = backdata;
                    if (status === 0) {
                        let { downLoadList, totalCount } = backdata;
                        $scope.downLoadList = downLoadList;
                        $scope.totalCount = totalCount;
                        if ($scope.totalCount === 0)
                            $scope.nolist = '暂无数据';
                        else
                            $scope.nolist = '';
                    } else {
                        base.msgModal('请求过于频繁，请稍后再试 ^_^');
                        $scope.nolist = '暂无数据';
                    }
                }).error(function () {
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                    $scope.nolist = '暂无数据';
                });
        }


        /**
         * @see 点击翻页查询数据
	     */
        $scope.pageChange = function () {
            //getList('main');
            getListFromServer('main');
        }

        $scope.$watch('$viewContentLoaded', function () {
            setTimeout(function () {
                ipcRenderer.send('getDownLoadDir');
                ipcRenderer.on('setDownLoadDir', (event, val) => {
                    $scope.downloadDir = val;
                    getListFromServer('main');
                });
            }, 500);
        });

    }]);

});
