define('projectlist', ['app', 'base'], function (app, base) {
    'use strict';
    app.controller('projectListCtrl', ['$scope', '$http',
        function ($scope, $http) {

            let electron = nodeRequire('electron');
            let { remote, ipcRenderer } = electron;

            //获取基础配置
            const { baseConfig, haveDownLoadStore } = remote.getGlobal('globalObject');


            let isFirstOpen = localStorage.getItem('isFirstOpen'), downLoadPidArr = [], downLoadPid = '';//, db = appdb.getConn();
            //获取缓存的手机号码
            $scope.phone = localStorage.getItem(baseConfig.LOCALSTORAGE.PHONE);
            //需要下载的门店的数据
            $scope.downLoadStoreList = [];

            $scope.downLoadSidArr = [];
            $scope.doenLoadSid = '';
            $scope.downLoadFileUrlArr = [];
            $scope.downLoadFileUrl = '';
            $scope.downLoadApplyFileUrlArr = [];
            $scope.downLoadApplyFileUrl = '';
            $scope.currPid = '';
            $scope.currSid = '';
            $scope.showDownLoadModal = false;

            // 初始化当前页码
            $scope.pageNow = 1;
            // 页面下拉选
            $scope.pageSizes = [{
                type: 10,
                title: '10'
            }, {
                type: 20,
                title: '20'
            }, {
                type: 50,
                title: '50'
            }, {
                type: 100,
                title: '100'
            }]
            $scope.pageSize = 20;


            //是否按照题号分组下拉选
            $scope.isQnumbers = [
                {
                    'title': '每个题号创建一个文件夹',
                    'val': 1
                }, {
                    'title': '所有附件保存同一个文件夹',
                    'val': 0
                }
            ]

            $scope.isQnumber = 1;


            //是否按照题号分组下拉选
            $scope.originalNames = [
                {
                    'title': '用自动命名后的文件名',
                    'val': 1
                }, {
                    'title': '用上传时原始文件名',
                    'val': 0
                }
            ]

            $scope.originalName = 1;


            /**
             * @see 常量快定义
             */
            const constant = {
                'sql': {
                    'insert': {
                        'project': `insert into project (uid,pid,numbers,title,fileSize,fileNumber) values (?,?,?,?,?,?)`,
                        'store': `insert into store (uid,pid,sid,number,title,fileSize,fileNumber,province,city,district) values (?,?,?,?,?,?,?,?,?,?)`,
                        'file': `insert into file (pid,sid,uid,title,fileSize,ftype,furl,bocuketName,address,createTime) values (?,?,?,?,?,?,?,?,?,?)`,
                        'download': `insert into download (pid,uid,sid,pnumbers,snumbers,sname,status,sprocess,fileSize,fileNumber) values (?,?,?,?,?,?,?,?,?,?)`
                    },
                    'update': {
                        'project': `update project set numbers = ?, title = ?,fileSize = ?,fileNumber = ?,status = ? where  uid = ? and pid = ?`,
                        'store': `update store set number = ? , title  = ? ,fileSize = ?,fileNumber = ?,province = ?,city = ?,district = ? where uid = ? and pid = ? and sid = ?`,
                        'file': `update file set title = ? ,fileSize = ? ,ftype = ?, furl = ?,bocuketName = ?,address = ?,createTime = ? where pid = ? and sid = ? and uid = ? and furl = ?`
                    },
                    'delete': {
                        'project': `delete from project`,
                        'store': `delete from store`,
                        'file': `delete from file`,
                        'download': `delete from download where status != 1 and pid = ? and uid = ? and  sid `
                    },
                    'select': {
                        'project': `select * from project where uid = ? and status = ?`,
                        'store': `select * from store where pid = ? and uid = ? and  status = ?`,
                        'file': `select * from file where pid = ? and uid = ? and sid = ? and  status = ?`,
                        'download': {
                            'status': `select sid from download where uid = ? and status = ? limit ?`,
                            'file': `select pid,sid from  download where uid = ?  order by  createTime desc limit  ?`
                        }
                    },
                    'status': {
                        'project': `update project set status = ? where uid = ? and pid `,
                        'store': `update store set status = ? where uid = ? and pid = ? and sid `,
                        'file': `update file set status = ? where uid = ? and pid = ? and  sid = ? and furl `
                    }
                },
                'common': {
                    'uid': localStorage.getItem(baseConfig.LOCALSTORAGE.UID),
                    'userType': localStorage.getItem(baseConfig.LOCALSTORAGE.USERTYPE),
                    'prefix': `${baseConfig.HTTP.HTTPSFIX}${baseConfig.SERVER.HOST}${baseConfig.API.FIX}`,
                    'suffix': `${baseConfig.SERVER.FIX}?apiKey=${baseConfig.API.APIKEY}`,
                    'cookieid': localStorage.getItem(baseConfig.LOCALSTORAGE.COOKIEID),
                    'email': localStorage.getItem(baseConfig.LOCALSTORAGE.EMAIL)
                },
                'url': {
                    'project': `clientdownload/projectSync`,
                    'store': `clientdownload/storeSync`,
                    'file': `clientupload/uploadFile`,
                    'save': `clientdownload/saveDownLoadStore`
                }
            }


            //appdb.dropTable(db);
            //if (!isFirstOpen)
            //appdb.initTable(db);

            /**
             * @see 系统退出登录
             */
            $scope.logout = function () {
                base.logout();
            }


            /**
             * @see 相关操作
             * @param from 操作来源
             * @param project 需要操作的项目
             */
            $scope.operation = function (from, project) {
                if (from === 'view')
                    viewStore(project);
                else if (from === 'projectSync')//同步项目
                    projectSync();
                else if (from === 'download') { //下载
                    //download(project)
                    $scope.modalActive = true;
                    $scope.showDownLoadModal = true;
                    $scope.currentDownLoadPro = project;
                } else if (from === 'drop') {
                    drop();
                } else if (from === 'downloadConfirm') {
                    const sendObj = {
                        'isQnumber': $scope.isQnumber,
                        'originalName': $scope.originalName
                    };
                    localStorage.setItem('saveDownLoadSettingInfo', JSON.stringify(sendObj));
                    ipcRenderer.send('saveDownLoadSettingInfo', sendObj);
                    ipcRenderer.on('saveDownLoadSettingInfoBack', (event, val) => {
                        if (val === 'ok') {
                            $scope.modalActive = false;
                            $scope.showDownLoadModal = false;
                            download(project);
                        }
                    });
                }
            }


            var viewStore = function (project) {
                let pNmbers = project[2], pTitle = project[3];
                localStorage.setItem('pNumber', pNmbers);
                localStorage.setItem('pTitle', `【${pNmbers}】 ${pTitle}`);
                let dirName = __dirname;
                dirName = dirName.substring(0, dirName.indexOf('template') + 8);
                location.href = `file://../${dirName}/store/storelist.html?pid=${project[0]}`;
            };

            /**
             * @see 同步项目
             */
            var projectSync = function () {
                $scope.modalActive = true;
                $scope.loadModal = true;
                $scope.loadingmsg = '别闹，加载是个很重要的事情~~~~~';
                $http.post(`${constant.common.prefix}${constant.url.project}${constant.common.suffix}`, {
                    'uid': constant.common.uid,
                    'userType': constant.common.userType
                }, {
                        'headers': baseConfig.HEADERS.ANGULAR
                    }).success(function (data) {
                        if (data.backdata.status === 0) {
                            let { backdata } = data, { projectList } = backdata;
                            if (projectList) {
                                $scope.projectList = projectList;
                                operationData('project', $scope.projectList);
                            }
                        } else {

                        }
                    }).error(function () {

                    });
            }

            /**
             * @see 清空数据
             */
            var drop = function () {
                db.transaction(function (t) {
                    t.executeSql(constant.sql.delete.project, [], function (t, r) {
                        dropStore();
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`delete project data  error code -->${code} and message -->${message}`);
                    });
                });
            }

            /**
             * @see 清空门店表数据
             */
            var dropStore = function () {
                db.transaction(function (t) {
                    t.executeSql(constant.sql.delete.store, [], function (t, r) {
                        dropFile();
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`delete store data error code -->${code} and message -->${message}`);
                    });
                });
            }

            /**
             *@see 清空文件表数据
             */
            var dropFile = function () {
                db.transaction(function (t) {
                    t.executeSql(constant.sql.delete.file, [], function (t, r) {
                        getList('refresh');
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`delete file data error code -->${code} and message -->${message}`);
                    });
                });
            }


            /**
             * @see 保存数据公共方法
             * @param tb 需要保存的数据表
             * @param saveDataList 需要保存的数据
             */
            var operationData = function (tb, saveDataList) {
                if (saveDataList.length > 0) {
                    saveData(tb, saveDataList);
                } else {
                    if (tb === 'project') {
                        if (downLoadPidArr) {
                            downLoadPid = `(${downLoadPidArr.join()})`;
                            updateStatus(tb, 'not in', 0);
                        } else {
                            getList('refresh');
                        }
                    } else if (tb === 'store') {
                        if ($scope.downLoadSidArr.length === 0) {
                            $scope.projectList.splice(0, 1);
                            operationData('project', $scope.projectList);
                        } else {
                            $scope.downLoadSid = `(${$scope.downLoadSidArr.join()})`;
                            updateStatus(tb, 'not in', 0);
                        }
                    } else if (tb === 'file') {
                        if ($scope.downLoadFileUrlArr.length === 0) {
                            operationData('applyFile', $scope.applyfileList);
                        } else {
                            $scope.downLoadFileUrl = `(${$scope.downLoadFileUrlArr.join()})`;
                            updateStatus(tb, 'not in', 0);
                        }
                    } else if (tb === 'applyFile') {
                        if ($scope.downLoadApplyFileUrlArr.length === 0) {
                            $scope.storetList.splice(0, 1);
                            operationData('store', $scope.storetList);
                        } else {
                            $scope.downLoadApplyFileUrl = `(${$scope.downLoadApplyFileUrlArr.join()})`;
                            updateStatus(tb, 'not in', 0);
                        }
                    }
                }
            }


            /**
             * @see 保存项目
             * @param tb 需要保存的数据表
             * @param projectList 需要保存的数据
             */
            var saveData = function (tb, saveDataList) {
                if (tb === 'project') {
                    let data = saveDataList[0];
                    downLoadPidArr.push(`'${data[0]}'`);
                    $scope.currPid = data[0];
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.insert.project, [data[1], data[0], data[2], data[3], data[6] + data[7], parseInt(data[4]) + parseInt(data[5])], function (t, r) {
                            //get strore
                            if (parseInt(data[4]) + parseInt(data[5]) > 0)
                                getStoreList('store', data[0]);
                        }, function (t, e) {
                            console.dir(e);
                            let { code, message } = e;
                            console.info(`insert into ${tb} error , code -->${code} and message -->${message}`);
                            updateData(tb, data, saveDataList);
                        });
                    });
                } else if (tb === 'store') {
                    let data = saveDataList[0];
                    $scope.downLoadSidArr.push(`'${data[2]}'`);
                    $scope.currSid = data[2];
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.insert.store, [data[0], data[1], data[2], data[3], data[4], data[10] + data[11], parseInt(data[8]) + parseInt(data[9]), data[5], data[6], data[7]], function (t, r) {
                            //get file
                            getFileList('file', $scope.currPid, data[2]);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`insert into ${tb} error , code -->${code} and message -->${message}`);
                            updateData(tb, data, saveDataList);
                        });
                    });
                } else if (tb === 'file') {
                    let data = saveDataList[0];
                    $scope.downLoadFileUrlArr.push(`'${data[6]}'`);
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.insert.file, [data[0], data[1], data[2], data[3], data[4], data[5], data[6], data[7], data[8], data[9]], function (t, r) {
                            saveDataList.splice(0, 1);
                            operationData(tb, saveDataList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`insert into ${tb} for answerfile is  error , code -->${code} and message -->${message}`);
                            updateData(tb, data, saveDataList);
                        });
                    });
                } else if (tb === 'applyFile') {
                    let data = saveDataList[0];
                    $scope.downLoadApplyFileUrlArr.push(`'${data[6]}'`);
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.insert.file, [data[0], data[1], data[2], data[3], data[4], data[5], data[6], data[7], data[8], data[9]], function (t, r) {
                            saveDataList.splice(0, 1);
                            operationData(tb, saveDataList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`insert into file for applyfile  is  error ,  code -->${code} and message -->${message}`);
                            updateData(tb, data, saveDataList);
                        });
                    });
                }
            }


            /**
             * @see 更新项目
             * @param tb 需要保存的数据表
             * @param data 需要更新的数据
             * @param saveDataList 数据集合
             */
            var updateData = function (tb, data, saveDataList) {
                if (tb === 'project') {
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.update.project, [data[2], data[3], data[6] + data[7], parseInt(data[4]) + parseInt(data[5]), data[1], data[0], 1], function (t, r) {
                            //get file
                            getStoreList('store', data[0]);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update ${tb} error code -->${code} and message -->${message}`);
                        });
                    });
                } else if (tb === 'store') {
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.update.store, [data[3], data[4], data[10] + data[11], parseInt(data[8]) + parseInt(data[9]), data[5], data[6], data[7], data[0], data[1], data[2]], function (t, r) {
                            //get file
                            getFileList('file', $scope.currPid, data[2]);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update ${tb} error code -->${code} and message -->${message}`);
                        });
                    });
                } else if (tb === 'file') {
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.update.file, [data[3], data[4], data[5], data[6], data[7], data[8], data[9], data[0], data[1], data[2], data[6]], function (t, r) {
                            saveDataList.splice(0, 1);
                            operationData(tb, saveDataList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update ${tb} for answerfile error code -->${code} and message -->${message}`);
                        });
                    });
                } else if (tb === 'applyFile') {
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.update.file, [data[3], data[4], data[5], data[6], data[7], data[8], data[9], data[0], data[1], data[2], data[6]], function (t, r) {
                            saveDataList.splice(0, 1);
                            operationData(tb, saveDataList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update file for applyfile error code -->${code} and message -->${message}`);
                        });
                    });
                }
            }

            /**
             * @see  变更状态
             */
            var updateStatus = function (tb, op, status) {
                if (tb === 'project') {
                    let updateStatusSql = `${constant.sql.status.project} ${op} ${downLoadPid}`;
                    db.transaction(function (t) {
                        t.executeSql(updateStatusSql, [status, constant.common.uid], function (t, r) {
                            getList('refresh');
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update error code -->${code} and message -->${message}`);
                        });
                    });
                } else if (tb === 'store') {
                    let updateStatusSql = `${constant.sql.status.store} ${op} ${$scope.downLoadSid}`;
                    db.transaction(function (t) {
                        t.executeSql(updateStatusSql, [status, constant.common.uid, $scope.currPid], function (t, r) {
                            $scope.projectList.splice(0, 1);
                            operationData('project', $scope.projectList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update status for ${tb} error code -->${code} and message -->${message}`);
                            $scope.projectList.splice(0, 1);
                            operationData('project', $scope.projectList);
                        });
                    });
                } else if (tb === 'file') {
                    let updateStatusSql = `${constant.sql.status.file} ${op} ${$scope.downLoadFileUrl}`;
                    db.transaction(function (t) {
                        t.executeSql(updateStatusSql, [status, constant.common.uid, $scope.currPid, $scope.currSid], function (t, r) {
                            operationData('applyFile', $scope.applyfileList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update status for ${tb} of answerfile error code -->${code} and message -->${message}`);
                            operationData('applyFile', $scope.applyfileList);
                        });
                    });
                } else if (tb === 'applyFile') {
                    let updateStatusSql = `${constant.sql.status.file} ${op} ${$scope.downLoadApplyFileUrl}`;
                    db.transaction(function (t) {
                        t.executeSql(updateStatusSql, [status, constant.common.uid, $scope.currPid, $scope.currSid], function (t, r) {
                            $scope.storetList.splice(0, 1);
                            operationData('store', $scope.storetList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`update status for ${tb} of answerfile error code -->${code} and message -->${message}`);
                            $scope.storetList.splice(0, 1);
                            operationData('store', $scope.storetList);
                        });
                    });
                }
            }


            /**
             * @see 通过pid获取对应门店数据
             * @param tb  需要操作的数据表
             * @param pid 需要获取数据的pid
             */
            var getStoreList = function (tb, pid) {
                if (pid) {
                    $http.post(`${constant.common.prefix}${constant.url.store}${constant.common.suffix}`, {
                        'pid': pid
                    }, {
                            'headers': baseConfig.HEADERS.ANGULAR
                        }).success(function (data) {
                            if (data.backdata.status === 0) {
                                let { backdata } = data, { storetList } = backdata;
                                if (storetList) {
                                    $scope.storetList = storetList;
                                    operationData(tb, $scope.storetList);
                                }
                            } else {

                            }
                        }).error(function (e) {
                            console.dir(e);
                        });
                }
            }

            /**
             * @see 获取某个项目，某个门店对应的附件信息
             * @param tb 需要操作的数据表
             * @param pid 项目ID
             * @param sid 门店ID
             */
            var getFileList = function (tb, pid, sid) {
                if (pid && sid) {
                    $http.post(`${constant.common.prefix}${constant.url.file}${constant.common.suffix}`,
                        {
                            'pid': pid, 'sid': sid
                        }, {
                            'headers': baseConfig.HEADERS.ANGULAR
                        }).success(function (data) {
                            if (data.backdata.status === 0) {
                                let { backdata } = data, { fileList, applyfileList } = backdata;
                                $scope.fileList = fileList;
                                $scope.applyfileList = applyfileList;
                                operationData('file', $scope.fileList);
                            } else {

                            }
                        }).error(function (e) {
                            console.dir(e);
                        });
                }
            }


            /**
             * @see 获取页面项目列表数据
             * @param from 方法调用来源
             */
            var getList = function (from) {
                downLoadPidArr = [], downLoadPid = '';
                $scope.downLoadSidArr = [];
                $scope.doenLoadSid = '';
                $scope.downLoadFileUrlArr = [];
                $scope.downLoadFileUrl = '';
                $scope.downLoadApplyFileUrlArr = [];
                $scope.downLoadApplyFileUrl = '';
                $scope.currPid = '';
                $scope.currSid = '';
                if (from === 'main') {
                    $scope.modalActive = true;
                    $scope.loadModal = true;
                    $scope.loadingmsg = '别闹，加载是个很重要的事情~~~~~';
                }
                let projectList = [];
                db.readTransaction(function (t) {
                    t.executeSql(constant.sql.select.project, [constant.common.uid, 1], function (t, r) {
                        for (var i = 0; i < r.rows.length; i++) {
                            projectList.splice(i, 0, r.rows[i]);
                        }
                        $scope.projectList = projectList;

                        if ($scope.projectList.length === 0)
                            $scope.nolist = '暂无数据';
                        else
                            $scope.nolist = '';

                        $scope.modalActive = false;
                        $scope.loadModal = false;
                        $scope.loadingmsg = '';
                        $scope.$apply();

                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`code is -->${code} and message is -->${message}`);
                    });
                });

            }

            /**
             * @see 下载项目对应该门店附件信息
             * @param  project 需要下载文件的项目
             */
            var download = function (project) {
                let pid = project[0];
                if (pid) {
                    $scope.currProject = project;
                    operationDownLoadData('all');
                }
            }


            /**
             * @see 下载全部数据
             * @param storeList 需要下载的门店的数据
             */
            var downLoadAllStore = function (storeList) {
                for (var store in storeList) {
                    if (!(storeList[store][9] === 0 && storeList[store][10] === 0))
                        $scope.downLoadStoreList.push(storeList[store]);
                }
                if ($scope.downLoadStoreList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    operationDownLoadData($scope.downLoadStoreList);
                }
            }

            /**
             * @see 对勾选的需要下载的门店数据进行操作
             * @param dataList 需要保存的保存的门店数据
             */
            var operationDownLoadData = function (dataList) {
                const dataObj = {};
                dataObj.pid = $scope.currProject[0];
                dataObj.uid = constant.common.uid;
                dataObj.cookieid = constant.common.cookieid;
                if (dataList !== 'all') {
                    const sidArr = [];
                    for (var store in dataList) {
                        sidArr.push(dataList[store][2]);
                    }
                    dataObj.sid = sidArr;
                }

                $http.post(`${constant.common.prefix}${constant.url.save}${constant.common.suffix}`, dataObj, {
                    'headers': baseConfig.HEADERS.ANGULAR
                }).success(function (data) {
                    let { backdata } = data, { status } = backdata;
                    if (status === 0) {
                        if (!haveDownLoadStore) {
                            const sendObj = {
                                'uid': constant.common.uid,
                                'cookieid': constant.common.cookieid,
                                'email': constant.common.email,
                                'op': 'only'
                            };
                            ipcRenderer.send('fileDownLoad', sendObj);
                            ipcRenderer.on('fileDownLoadMessage', (event, val) => {
                                if (val === 'only')
                                    main('refresh');
                            });
                        }
                    } else {
                        base.msgModal('请求过于频繁，请稍后再试 ^_^');
                    }
                }).error(function () {
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                });
            }


            /**
             * @see 删除之前选中的门店数据
             * @param sidStr 需要删除的门店id
             * @param dataList 需要下载的数据
             */
            var deleteDownLoadData = function (sidStr, dataList) {
                let delSql = `${constant.sql.delete.download} in ${sidStr}`;
                db.transaction(function (t) {
                    t.executeSql(delSql, [$scope.currProject[0], constant.common.uid], function (t, r) {
                        saveDownLoadData(dataList);
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`delete download eror is come  , code -->${code} and message -->${message}`);
                    });
                });
            }

            /**
             * @see 保存数据至数据库
             */
            var saveDownLoadData = function (dataList) {
                if (dataList.length === 0) {
                    //query data and download start
                    isexistDownLoadData();
                } else {
                    const store = dataList[0];
                    db.transaction(function (t) {
                        t.executeSql(constant.sql.insert.download, [$scope.currProject[0], constant.common.uid, store[2], $scope.currProject[2].toString(), store[3], store[4], 0, 0, store[9], store[10]], function (t, r) {
                            dataList.splice(0, 1);
                            saveDownLoadData(dataList);
                        }, function (t, e) {
                            let { code, message } = e;
                            console.info(`insert into ${store[2]} error , code -->${code} and message -->${message}, because  is the sid is downloading`);
                            dataList.splice(0, 1);
                            saveDownLoadData(dataList);
                        });
                    });
                }
            }


            /**
             * @see 判断是否存在带下载的数据
             */
            var isexistDownLoadData = function () {
                db.readTransaction(function (t) {
                    t.executeSql(constant.sql.select.download.status, [constant.common.uid, 1, 1], function (t, r) {
                        if (r.rows.length === 0)
                            getNeedDownLoadData();
                        else
                            console.info(`have sid file is downloading...`);
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`select status by uid error , code -->${code} and message -->${message}`);
                    });
                });
            }


            /**
             * @see 获取需要下载的门店数据
             */
            var getNeedDownLoadData = function () {
                db.readTransaction(function (t) {
                    t.executeSql(constant.sql.select.download.file, [constant.common.uid, 1], function (t, r) {
                        if (r.rows.length !== 0) {
                            const result = r.rows[0];
                            let sid = result.sid;
                            downloadFile(sid);
                        }
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`select wait download file  by uid error , code -->${code} and message -->${message}`);
                    });
                });
            }

            /**
             * @see 下载某个门店的附件
             * @param sid 需要下载的附件的门店id
             */
            var downloadFile = function (sid) {
                let pid = $scope.currProject[0];
            }


            /**
             * @see 从服务器直接获取项目列表
             * @param from 方法调用来源
             */
            var getListFromServer = function (from) {
                localStorage.removeItem('pNumber');
                localStorage.removeItem('pTitle');
                localStorage.removeItem('currDownLoadPid');

                $http.post(`${constant.common.prefix}${constant.url.project}${constant.common.suffix}`, {
                    'uid': constant.common.uid,
                    'userType': constant.common.userType,
                    'cookieid': constant.common.cookieid,
                    'pageSize': $scope.pageSize,
                    'pageNow': $scope.pageNow
                }, {
                        'headers': baseConfig.HEADERS.ANGULAR
                    }).success(function (data) {
                        if (data.backdata.status === 0) {
                            let { backdata } = data, { projectList, totalCount } = backdata;
                            $scope.projectList = projectList;
                            $scope.totalCount = totalCount;
                            if ($scope.totalCount === 0)
                                $scope.nolist = '暂无数据';
                            else
                                $scope.nolist = '';
                        } else {
                            $scope.nolist = '暂无数据';
                            base.msgModal('请求过于频繁，请稍后再试 ^_^');
                        }

                    }).error(function () {
                        $scope.nolist = '暂无数据';
                        base.msgModal('请求过于频繁，请稍后再试 ^_^');
                    });
            }


            /**
             * @see 点击翻页查询数据
             */
            $scope.pageChange = function () {
                getListFromServer('');
            }

            /**
             * @see ngrepeat 加载完成0.5s之后调用
             */
            $scope.$on('ngRepeatFinished', function () {
                $scope.modalActive = false;
                $scope.loadModal = false;
                $scope.loadingmsg = '';
            });

            $scope.$watch('$viewContentLoaded', function () {
                setTimeout(function () {
                    main('main');
                }, 500);
            });


            /**
             * @see 把excel文件发送猫哥服务器
             *
             */
            $scope.uploadFileToServer = function (file, pid) {
                let oData = new FormData();
                let currentPro = '';
                for (var k in $scope.projectList) {
                    if ($scope.projectList[k][0] === pid) {
                        currentPro = $scope.projectList[k];
                        break;
                    }
                }
                oData.append('uploadFile', file);
                oData.append('cookieid', constant.common.cookieid);
                oData.append('uid', constant.common.uid);
                oData.append('pNumber', currentPro[2]);
                oData.append('cid', currentPro[7]);
                oData.append('pid', pid);

                $http.post(`${constant.common.prefix}${constant.url.file}${constant.common.suffix}`, oData, {
                    'headers': {
                        'Content-Type': undefined
                    },
                    'transformRequest': angular.identity
                }).success(function (data) {
                    console.log(data);
                    if (data.backdata.status === 0) {
                        base.msgModal('excel文件已上传成功，请在正在上传页面查看.');
                    }
                }).error(function () {
                    $scope.nolist = '暂无数据';
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                });
            }


            /**
             * @see 关闭弹出框
             */
            $scope.closeModal = function () {
                $scope.modalActive = false;
                $scope.showDownLoadModal = false;
            }


            /**
             * @see 主方法 默认加载数据
             */
            var main = function (from) {
                if (from === 'main') {
                    $scope.modalActive = true;
                    $scope.loadModal = true;
                    $scope.loadingmsg = '加载中，请稍后';
                }
                else if (from === 'refresh') {
                    base.msgModal('该项目所有门店已经加入下载队列，请点击正在下载查看.');
                }
                getListFromServer('main');
            };
        }]).directive('onRenderFinish', function ($timeout) {// 监听加载状态
            return {
                restrict: 'AC',
                link: function (scope, element, attr) {
                    if (scope.$last === true) {
                        $timeout(function () {
                            scope.$emit('ngRepeatFinished');
                        }, 500);
                    }
                }
            }
        }).directive('fileChange',
            [
                function () {
                    return {
                        restrict: 'AC',
                        link: function (scope, element, attrs) {
                            element
                                .bind(
                                    'change',
                                    function () {
                                        var file = element[0].files[0];
                                        if (file) {
                                            var reg = /^.*\.(?:xls|xlsx)$/i; //文件名可以带空格
                                            if (reg.test(file.path)) {//校验不通过
                                                var pid = element[0].attributes['data-pid'].value;
                                                scope.uploadFileToServer(file, pid);
                                            } else {
                                                alert("请上传excel格式的文件!");
                                                return;
                                            }
                                        }
                                    })
                        }
                    }
                }]);
});
