define('storelist', ['app', 'base'], function (app, base) {
    'use strict';
    app.controller('storeListCtrl', ['$scope', '$http', function ($scope, $http) {
        const electron = nodeRequire('electron');
        const { remote, ipcRenderer } = electron;

        //获取基础配置
        const { baseConfig, haveDownLoadStore } = remote.getGlobal('globalObject');
        //获取缓存的手机号码
        $scope.phone = localStorage.getItem(baseConfig.LOCALSTORAGE.PHONE);
        //需要下载的门店的数据
        $scope.downLoadStoreList = [];
        // 初始化当前页码
        $scope.pageNow = 1;
        // 页面下拉选
        $scope.pageSizes = [{
            type: 10,
            title: '10'
        }, {
            type: 20,
            title: '20'
        }, {
            type: 50,
            title: '50'
        }, {
            type: 100,
            title: '100'
        }]
        $scope.pageSize = 20;

        /**
         * @see 常量快定义
         */
        const constant = {
            'sql': {
                'select': {
                    'download': {
                        'list': `select pid,sid,pnumbers,snumbers,sname,status,fileSize,fileSizeDown,fileNumber,fileNumberDown from download  where uid = ?`,
                        'status': `select sid from download where uid = ? and status = ? limit ?`,
                        'file': `select pid,sid from  download where uid = ?  order by  createTime desc limit  ?`
                    }
                },
                'insert': {
                    'download': `insert into download (pid,uid,sid,pnumbers,snumbers,sname,status,sprocess,fileSize,fileNumber) values (?,?,?,?,?,?,?,?,?,?)`
                },
                'delete': {
                    'download': `delete from download where status != 1 and pid = ? and uid = ? and  sid `
                }
            },
            'common': {
                'uid': localStorage.getItem(baseConfig.LOCALSTORAGE.UID),
                'userType': localStorage.getItem(baseConfig.LOCALSTORAGE.USERTYPE),
                'prefix': `${baseConfig.HTTP.HTTPSFIX}${baseConfig.SERVER.HOST}${baseConfig.API.FIX}`,
                'suffix': `${baseConfig.SERVER.FIX}?apiKey=${baseConfig.API.APIKEY}`,
                'cookieid': localStorage.getItem(baseConfig.LOCALSTORAGE.COOKIEID),
                'email': localStorage.getItem(baseConfig.LOCALSTORAGE.EMAIL)
            },
            'url': {
                'save': `clientdownload/saveDownLoadStore`,
                'list': `clientdownload/storeSync`
            }
        }

        /**
         * @see 系统退出登录
         */
        $scope.logout = function () {
            base.logout();
        }

        // 全选 全不选
        $scope.allCheck = false;
        $scope.checkAll = function () {
            $scope.allCheck = !$scope.allCheck;
            for (var i = 0, j = $scope.storetList.length; i < j; i++) {
                if (!($scope.storetList[i][9] === 0 && $scope.storetList[i][10] === 0))
                    $scope.storetList[i].checked = $scope.allCheck;
            }
        };

        /**
        * @see 单选与不选
        */
        $scope.boxChecked = function (store) {
            if (!(store[9] === 0 && store[10] === 0)) {
                $scope.checked = !$scope.checked;
                store.checked = $scope.checked;
            }
        }

        /**
         * @see 操作
         * @param from 方法来源
         * @param store  需要下载的门店数据
         */
        $scope.operation = function (from, store) {
            if (from === 'view')
                viewFile(store);
            else if (from === 'download') {//下载
                $scope.downLoadStoreList = [];
                $scope.downLoadStoreList.push(store);
                operationDownLoadData($scope.downLoadStoreList);
            } else if (from === 'batchdownload') {//批量下载勾选门店
                $scope.downLoadStoreList = [];
                for (var i = 0, j = $scope.storetList.length; i < j; i++) {
                    if ($scope.storetList[i].checked)
                        $scope.downLoadStoreList.push($scope.storetList[i]);
                }

                if ($scope.downLoadStoreList.length === 0) {
                    base.msgModal('请至少勾选一个门店');
                } else {
                    operationDownLoadData($scope.downLoadStoreList);
                }
            } else if (from === 'downloadall') {//点击下载全部门店
                // getListFormServer('all');
                operationDownLoadData('all');
            }
        }


        /**
         * @see 下载全部数据
         * @param storeList 需要下载的门店的数据
         */
        var downLoadAllStore = function (storeList) {
            for (var store in storeList) {
                if (!(storeList[store][9] === 0 && storeList[store][10] === 0))
                    $scope.downLoadStoreList.push(storeList[store]);
            }
            if ($scope.downLoadStoreList.length === 0) {
                base.msgModal('请至少勾选一个门店');
            } else {
                operationDownLoadData($scope.downLoadStoreList);
            }
        }


        /**
         * @see 查看某个门店对应的附件信息
         * @param store 需要查看的附件的门店
         */
        var viewFile = function (store) {
            let dirName = __dirname;
            dirName = dirName.substring(0, dirName.indexOf('template') + 8);
            location.href = `file://${dirName}/file/filelist.html`;
        }


        /**
         * @see 对勾选的需要下载的门店数据进行操作
         * @param dataList 需要保存的保存的门店数据
         */
        var operationDownLoadData = function (dataList) {
            const dataObj = {};
            dataObj.pid = $scope.pid;
            dataObj.uid = constant.common.uid;
            dataObj.cookieid = constant.common.cookieid;
            if (dataList !== 'all') {
                const sidArr = [];
                for (var store in dataList) {
                    sidArr.push(dataList[store][2]);
                }

                dataObj.sid = sidArr;
            }

            $http.post(`${constant.common.prefix}${constant.url.save}${constant.common.suffix}`, dataObj, {
                'headers': baseConfig.HEADERS.ANGULAR
            }).success(function (data) {
                let { backdata } = data, { status } = backdata;
                if (status === 0) {
                    if (!haveDownLoadStore) {
                        const sendObj = {
                            'uid': constant.common.uid,
                            'cookieid': constant.common.cookieid,
                            'email': constant.common.email,
                            'op': 'only'
                        };
                        ipcRenderer.send('fileDownLoad', sendObj);
                        ipcRenderer.on('fileDownLoadMessage', (event, val) => {
                            console.info(`val-->${val}`)
                            if (val === 'only')
                                getListFormServer('refresh');
                        });
                    }
                } else {
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                }
            }).error(function () {
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
            });
            // if (dataList.length !== 0) {
            //     const sidArr = [];
            //     for (var store in dataList) {
            //         sidArr.push(`'${dataList[store][2]}'`);
            //     }
            //     if (sidArr) {
            //         let sidStr = `(${sidArr.join()})`;
            //         deleteDownLoadData(sidStr, dataList);
            //     }
            // }
        }


        /**
         * @see 删除之前选中的门店数据
         * @param sidStr 需要删除的门店id
         * @param dataList 需要下载的数据
         */
        var deleteDownLoadData = function (sidStr, dataList) {
            let delSql = `${constant.sql.delete.download} in ${sidStr}`;
            db.transaction(function (t) {
                t.executeSql(delSql, [$scope.pid, constant.common.uid], function (t, r) {
                    saveDownLoadData(dataList);
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`delete download eror is come  , code -->${code} and message -->${message}`);
                });
            });
        }

        /**
         * @see 保存数据至数据库
         */
        var saveDownLoadData = function (dataList) {
            if (dataList.length === 0) {
                //query data and download start 
                isexistDownLoadData();
            } else {
                var store = dataList[0];
                db.transaction(function (t) {
                    t.executeSql(constant.sql.insert.download, [$scope.pid, constant.common.uid, store[2], localStorage.getItem('pNumber'), store[3], store[4], 0, 0, store[9], store[10]], function (t, r) {
                        dataList.splice(0, 1);
                        saveDownLoadData(dataList);
                    }, function (t, e) {
                        let { code, message } = e;
                        console.info(`insert into ${store[2]} error , code -->${code} and message -->${message}, because  is the sid is downloading`);
                        dataList.splice(0, 1);
                        saveDownLoadData(dataList);
                    });
                });
            }
        }


        /**
         * @see 判断是否存在带下载的数据
         */
        var isexistDownLoadData = function () {
            db.readTransaction(function (t) {
                t.executeSql(constant.sql.select.download.status, [constant.common.uid, 1, 1], function (t, r) {
                    if (r.rows.length === 0)
                        getNeedDownLoadData();
                    else
                        console.info(`have sid file is downloading...`);
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`select status by uid error , code -->${code} and message -->${message}`);
                });
            });
        }


        /**
         * @see 获取需要下载的门店数据
         */
        var getNeedDownLoadData = function () {
            db.readTransaction(function (t) {
                t.executeSql(constant.sql.select.download.file, [constant.common.uid, 1], function (t, r) {
                    if (r.rows.length !== 0) {
                        const result = r.rows[0];
                        let pid = result.pid, sid = result.sid;
                        localStorage.setItem('currDownLoadPid', pid);
                        downloadFile(sid);
                    }
                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`select wait download file  by uid error , code -->${code} and message -->${message}`);
                });
            });
        }

        /**
         * @see 下载某个门店的附件
         * @param sid 需要下载的附件的门店id
         */
        var downloadFile = function (sid) {
            let pid = localStorage.getItem('currDownLoadPid');
            console.info(`sid-->${sid} and pid -->${pid}`);
        }

        //获取pid
        let pid = base.getQueryStringParam('pid');
        if (pid)
            $scope.pid = pid;
        /**
         * @see 获取数据
         */
        var getList = function (from) {
            let storetList = [];
            db.readTransaction(function (t) {
                t.executeSql(constant.sql.select.store, [$scope.pid, constant.common.uid, 1], function (t, r) {
                    for (var i = 0; i < r.rows.length; i++) {
                        storetList.splice(i, 0, r.rows[i]);
                    }
                    $scope.storetList = storetList;

                    if ($scope.storetList.length === 0) {
                        $scope.nolist = '暂无数据';
                    } else {
                        $scope.ptitle = `【${$scope.storetList[0].numbers}】${$scope.storetList[0].ptitle}`;
                        $scope.nolist = '';
                    }

                    $scope.modalActive = false;
                    $scope.loadModal = false;
                    $scope.loadingmsg = '';
                    $scope.$apply();

                }, function (t, e) {
                    let { code, message } = e;
                    console.info(`code is -->${code} and message is -->${message}`);
                });
            });
        }

        /**
         * @see 获取数据
         */
        var getListFormServer = function (from) {

            if (from === 'main') {
                $scope.modalActive = true;
                $scope.loadModal = true;
                $scope.loadingmsg = '别闹，加载是个很重要的事情~~~~~';
            }

            if ($scope.pid) {

                const data = {};
                data.pid = $scope.pid;
                data.cookieid = constant.common.cookieid;
                data.uid = constant.common.uid;
                if (from === 'main') {
                    data.pageSize = $scope.pageSize;
                    data.pageNow = $scope.pageNow;
                }
                data.from = from;

                $http.post(`${constant.common.prefix}${constant.url.list}${constant.common.suffix}`, data, {
                    'headers': baseConfig.HEADERS.ANGULAR
                }).success(function (data) {
                    if (data.backdata.status === 0) {
                        if (from === 'main' || from === 'refresh') {
                            let { backdata } = data, { storetList, totalCount } = backdata;
                            $scope.storetList = storetList;
                            $scope.totalCount = totalCount;
                            if ($scope.totalCount === 0)
                                $scope.nolist = '暂无数据';
                            else
                                $scope.nolist = '';

                            $scope.ptitle = localStorage.getItem('pTitle');
                        } else if (from === 'all') {
                            let { backdata } = data, { storetList } = backdata;
                            downLoadAllStore(storetList);
                        }
                    } else {
                        base.msgModal('请求过于频繁，请稍后再试 ^_^');
                        $scope.nolist = '暂无数据';
                    }
                }).error(function (e) {
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                    $scope.nolist = '暂无数据';
                });
            } else {
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
                $scope.nolist = '暂无数据';
            }

            if (from === 'main') {
                $scope.modalActive = false;
                $scope.loadModal = false;
                $scope.loadingmsg = '';
            }

            if (from === 'refresh') {
                base.msgModal('门店已经加入到下载队列，请点击正在下载查看.');
            }
        }

        /**
	     * @see 点击翻页查询数据
	     */
        $scope.pageChange = function () {
            getListFormServer('main');
        }

        $scope.$watch('$viewContentLoaded', function () {
            setTimeout(function () {
                getListFormServer('main')
            }, 500);
        });

    }]);
});
