define('uploadstorelist', [
    'app', 'base'
], function (app, base) {
    'use strict';
    app.controller('uploadFileCtrl', ['$scope', '$http', function ($scope, $http) {
        let electron = nodeRequire('electron');
        let {remote, ipcRenderer} = electron;

        // 初始化当前页码
        $scope.pageNow = 1;
        // 页面下拉选
        $scope.pageSizes = [{
            type: 10,
            title: '10'
        }, {
            type: 20,
            title: '20'
        }, {
            type: 50,
            title: '50'
        }, {
            type: 100,
            title: '100'
        }]
        $scope.pageSize = 20;

        //获取基础配置
        const {baseConfig} = remote.getGlobal('globalObject');
        /**
         * @see 常量快定义
         */
        const constant = {
            'url': {
                'getUploadList': 'clientupload/uploadFileChange',
                'beginUpFile': 'clientupload/uploadFileChange',
                'queryList': '1234',
                'deleteList': 'deleteUploadFiles'
            },
            'common': {
                'uid': localStorage.getItem(baseConfig.LOCALSTORAGE.UID),
                'prefix': `${baseConfig.HTTP.HTTPSFIX}${baseConfig.SERVER.HOST}${baseConfig.API.FIX}`,
                'suffix': `${baseConfig.SERVER.FIX}?apiKey=${baseConfig.API.APIKEY}`,
                'cookieid': localStorage.getItem(baseConfig.LOCALSTORAGE.COOKIEID)
            }
        }

        /**
         * @see 点击翻页查询数据
         */
        $scope.pageChange = function () {
            getListFromServer('');
        }


        /**
         * @see 系统退出登录
         */
        $scope.logout = function () {
            base.logout();
        }

        // 全选 全不选
        $scope.allCheck = false;
        $scope.checkAll = function () {
            $scope.allCheck = !$scope.allCheck;
            for (var i = 0, j = $scope.items.length; i < j; i++) {
                $scope.items[i].checked = $scope.allCheck;
            }
        };

        /**
         * @see 单选与不选
         */
        $scope.boxChecked = function (item) {
            $scope.checked = !$scope.checked;
            item.checked = $scope.checked;
        }


        /**
         * @see 从服务器直接获取项目列表
         * @param from 方法调用来源
         */
        var getListFromServer = function () {
            let param = {
                'uid': constant.common.uid,
                'cookieid': constant.common.cookieid,
                'pageSize': $scope.pageSize,
                'pageNow': $scope.pageNow,
                'status': '0',
                'queryProjectNum': $scope.pNumbers || '',
                'queryStoreName': $scope.storeName || '',
                'queryQuesNum': $scope.pNum || ''
            };
            // console.log(param);
            $http.post(`${constant.common.prefix}${constant.url.getUploadList}${constant.common.suffix}`, param, {
                'headers': baseConfig.HEADERS.ANGULAR
            }).success(function (data) {
                if (data.backdata.status === 0) {
                    console.log(data);
                    let {backdata: {items, totalCount} = {}} = data;
                    $scope.items = items;
                    $scope.totalCount = totalCount;
                    if ($scope.totalCount === 0)
                        $scope.nolist = '暂无数据';
                    else
                        $scope.nolist = '';
                } else {
                    $scope.nolist = '暂无数据';
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                }

            }).error(function () {
                $scope.nolist = '暂无数据';
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
            });
        }


        /*
        * 开始上传的方法
        * */
        $scope.operation = function (type){
            let items = [];
            // let localPathArr = ['D:\\gj\\1.jpg', 'D:\\gj\\2.jpg'];

            if(type == 'all'){
                for( let item in $scope.items ){
                    items.push(item);
                };
            }else if( type == 'fail'){
                for( let item in $scope.items ){
                    if($scope.items[item].checked){
                        items.push(item);
                    }
                };
            };
            //开始上传 获取选中的
            ipcRenderer.send('startUpfile', items);
        };

        /*
        *  删除的方法
        * */
        $scope.deleteTask = function (){
            let ids = [];
            for( let item in $scope.items ){
                if($scope.items[item].checked){
                    ids.push(item[0]);
                }
            };
            let param = {
                ids: ids
            };
            $http.post(`${constant.common.prefix}${constant.url.deleteList}${constant.common.suffix}`, param, {
                'headers': baseConfig.HEADERS.ANGULAR
            }).success(function (data) {
                console.log(data);
                if (data.backdata.status === 0) {
                    let {backdata: {items, totalCount} = {}} = data;
                    $scope.items = items;
                    $scope.totalCount = totalCount;
                    if ($scope.totalCount === 0)
                        $scope.nolist = '暂无数据';
                    else
                        $scope.nolist = '';
                } else {
                    $scope.nolist = '暂无数据';
                    base.msgModal('请求过于频繁，请稍后再试 ^_^');
                }

            }).error(function () {
                $scope.nolist = '暂无数据';
                base.msgModal('请求过于频繁，请稍后再试 ^_^');
            });
        }


        /*
        *  真正的上传
        * */
        let realStartUpFile = function (localPathArr){
                ipcRenderer.send('startUpfile', localPathArr);
                // $http.post(`${constant.common.prefix}${constant.url.beginUpFile}${constant.common.suffix}`, {}, {
                //     'headers': baseConfig.HEADERS.ANGULAR
                // }).success(function (data) {
                //     console.log(data);
                //     if (data.backdata.status === 0) {
                //         ipcRenderer.send('startUpfile', localPathArr[num]);
                //     }
                // }).error(function () {
                //     $scope.nolist = '暂无数据';
                //     base.msgModal('请求过于频繁，请稍后再试 ^_^');
                // });
        };

        // /*
        // *  接收上传成功后的调用下一个的监听
        // * */
        // let  upFileNext = function (){
        //     ipcRenderer.on('upFileNext', (event, val) => {
        //         realStartUpFile();
        //     });
        // }

        /**
         * @see 查询正在上传列表
         *
         */
        $scope.queryStore = function (from) {
            getListFromServer();

        }
        /**
         * @see 主方法 默认加载数据
         */
        var main = function (from) {
            getListFromServer();
        }();
    }]);
});
