define('base', ['bootbox'], function (bootbox) {
    'use strict';
    return {
        /**
         * @see bse64加密
         */
        'b64_encode': function (s) {
            return this.base64encode(s);
        },
        /**
         * @see bse64加密
         */
        'base64encode': function (input) {
            let output = '', _keyStr = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=', chr1, chr2, chr3, enc1, enc2, enc3, enc4, i = 0;
            input = this.utf8Encode(input);
            while (i < input.length) {
                chr1 = input.charCodeAt(i++);
                chr2 = input.charCodeAt(i++);
                chr3 = input.charCodeAt(i++);
                enc1 = chr1 >> 2;
                enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
                enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
                enc4 = chr3 & 63;
                if (isNaN(chr2)) {
                    enc3 = enc4 = 64;
                } else if (isNaN(chr3)) {
                    enc4 = 64;
                }
                output = output + _keyStr.charAt(enc1) + _keyStr.charAt(enc2)
                    + _keyStr.charAt(enc3) + _keyStr.charAt(enc4);
            }
            return output;
        },
        /**
         * @see utf-8加密
         */
        'utf8Encode': function (string) {
            string = string.replace(/\r\n/g, "\n");
            let utftext = "";
            for (var n = 0; n < string.length; n++) {
                var c = string.charCodeAt(n);
                if (c < 128) {
                    utftext += String.fromCharCode(c);
                } else if ((c > 127) && (c < 2048)) {
                    utftext += String.fromCharCode((c >> 6) | 192);
                    utftext += String.fromCharCode((c & 63) | 128);
                } else {
                    utftext += String.fromCharCode((c >> 12) | 224);
                    utftext += String.fromCharCode(((c >> 6) & 63) | 128);
                    utftext += String.fromCharCode((c & 63) | 128);
                }
            }
            return utftext;
        },
        /**
         * @see 消息提示框
         * @param msg 提示消息
         * @param callbackurl 回调链接
         */
        'msgModal': function (msg, callbackurl) {
            bootbox
                .alert({
                    'buttons': {
                        'ok': {
                            'label': '确定',
                            'className': 'blue'
                        }
                    },
                    'message': msg || '操作提示',
                    'title': '<i class="icon-info"></i><span style="margin-left:.5em;">温馨提示</span>',
                    'callback': function () {
                        if (callbackurl)
                            location.href = callbackurl;
                    }
                });
        },
        /**
         * @see 删除确认框
         * @param msg  提示信息
         */
        'confirm': function (msg, fn) {
            bootbox.setLocale("zh_CN");
            bootbox.confirm({
                'buttons': {
                    'confirm': {
                        'className': 'blue'
                    }
                },
                'message': msg || '此操作具有风险性，您确认删除么?',
                'title': '<i class="icon-info"></i><span style="margin-left:.5em;">温馨提示</span>',
                'callback': function (result) {
                    return fn(result);
                }
            });
        },
        /**
         *@see 传递参数名获取导航栏参数值
         *@param name 参数名
         *@returns
         */
        'getQueryStringParam': function (name) {
            var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
            var r = window.location.search.substr(1).match(reg);
            if (r != null)
                return unescape(r[2]);
            return '';
        },
        /**
         * @see 退出登录
         */
        'logout': function () {
            const electron = nodeRequire('electron');
            const { ipcRenderer } = electron;
            ipcRenderer.send('hasDownLoadTask');
            ipcRenderer.on('hasDownLoadTaskBack', (event, val) => {
                if (val) {
                    this.confirm('当前又正在下载的任务，退出将自动停止下载，您确认么？', (result) => {
                        if (result) {
                            ipcRenderer.send('logout');
                            ipcRenderer.on('logoutBack', (arg) => {
                                //if (arg === 'ok') {
                                    this.loginConfirm();
                               //}
                            });
                        }
                    });
                } else {
                    this.confirm('您确认退出账号么？', (result) => {
                        if (result) {
                            this.loginConfirm();
                        }
                    });
                }
            });
        },
        /**
         * @see 清楚缓存信息并最终退出登录
         */
        'loginConfirm' : function (){
            localStorage.removeItem('storagePhone');
            localStorage.removeItem('storageEmail');
            localStorage.removeItem('storageUid');
            localStorage.removeItem('storageUserType');
            localStorage.removeItem('pNumber');
            localStorage.removeItem('pTitle');
            localStorage.removeItem('storageLoginInfo');
            let dirName = __dirname;
            dirName = dirName.substring(0, dirName.indexOf('template') + 8);
            location.href = `file://${dirName}/login/login.html`;
        },
        /**
         * @see 生成随机数
         * @param len 需要生成的随机数的长度,默认32
         * @param radix 生成随机数的基数
         */
        'UUID': function (len, radix) {
            if (!len) {
                len = 32;
            }
            if (radix) {
                radix = 36;
            }

            var chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'
                .split('');
            var uuid = [], i;
            radix = radix || chars.length;
            if (len) {
                for (i = 0; i < len; i++)
                    uuid[i] = chars[0 | Math.random() * radix];
            } else {
                var r;
                uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
                uuid[14] = '4';
                for (i = 0; i < 36; i++) {
                    if (!uuid[i]) {
                        r = 0 | Math.random() * 16;
                        uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
                    }
                }
            }
            return uuid.join('');
        }
    }
});