/*
 * 发送请求工具类
 *
 * Copyright (c) 2014-2020 zhaocaimao
 *
 * Date: 2017-02-21T21:07:00Z
 */

'use strict';
/*
 * require modules
 */
const urllib = require('urllib');
/*
 * define class
 */
const urlLib = {};
/**
 * @see 方法第三方接口通用工具类
 * @param url  请求地址
 * @param type  请求类型
 * @param param  请求JSON数据
 * @param callback 方法回调函数
 * @return callback 方法回调函数
 */
let send = function (url, type, param, callback) {
    const opt = {
        method: type || 'POST',
        headers: {
            'Content-Type': 'application/json;Charset=UTF-8'
        },
        // followRedirect: true,
        //timeout: [1000 * 5, 1000 * 60],//链接5s超时，响应1min超时
        // dataType: 'JSON',
        data: param
    };

    urllib.request(url, opt, (err, data, res) => {
        if (res.status === 200 && res.statusCode === 200) {
            try {
                let finaldata = JSON.parse(data);
                return callback(null, finaldata);
            } catch (error) {
                return callback(error, null);
            }
        } else {
            return callback(err, null);
        }
    });
};
/**
 * @see 发送POST请求
 * @param url  请求地址
 * @param type  请求类型
 * @param param  请求JSON数据
 * @param callback 方法回调函数
 */
urlLib.POST = function (url, param, callback) {
    return send(url, 'POST', param, callback);
};
/**
 * @see 发送GET请求
 * @param url  请求地址
 * @param type  请求类型
 * @param param  请求JSON数据
 * @param callback 方法回调函数
 */
urlLib.GET = function (url, param, callback) {
    return send(url, 'GET', param, callback);
};
/**
 * @see 发送PUT请求
 * @param url  请求地址
 * @param type  请求类型
 * @param param  请求JSON数据
 * @param callback 方法回调函数
 */
urlLib.PUT = function (url, param, callback) {
    return send(url, 'PUT', param, callback);
};
/**
 * @see 发送DELETE请求
 * @param url  请求地址
 * @param type  请求类型
 * @param param  请求JSON数据
 * @param callback 方法回调函数
 */
urlLib.DELETE = function (url, param, callback) {
    return send(url, 'DELETE', param, callback);
};

/*
 * exports urlLib
 */
module.exports = urlLib;