/*
 * ! javascript file for page v1.0
 *
 * Copyright (c) 2014-2020 zhaocaimao
 *
 * Date: 2016-4-17T13:37:00Z
 */

/**
 * @see 分页控件
 *
 */

'use strict';

define('pagination', ['app'], function (app) {
	app.directive('pagination', function () {
		return {
			restrict: 'A',// A 用于元素的 Attribute，这是默认值
			//scope（1）默认值false。表示继承父作用域;
			//（2）true。表示继承父作用域，并创建自己的作用域（子作用域）;
			//（3）{}。表示创建一个全新的隔离作用域；
			scope: { // 为了一个页面可以出现多个分页组件，这里采用隔离scope
				pageSize: '=',
				// =表示双向绑定 每页显示多少条
				totalCount: '=',
				// 总条数
				pageNow: '=',
				// 当前页码
				listSize: '@',
				// @ 单项绑定 页面显示多个个页码
				onPageChange: '&' // &表示函数绑定
				// 翻页事件通知，响应事件通过读取currentPage来获取当前页
			},
			controller: ['$scope', 'pagerConfig', '$timeout', function ($scope, pagerConfig, $timeout) {
				$scope.totalPages = 0;
				$scope.totalCount = 0;
				$scope.pages = [];

				// 重新计算显示的页码
				var recalc = function (rangeInt) {
					var pageRange = Math.min(
						$scope.listSize, $scope.totalPages);
					$scope.pages = [];
					rangeInt = rangeInt || 0;
					var base = rangeInt * $scope.listSize;
					for (var i = 1; i <= pageRange; i++) {
						var page = {};
						if (rangeInt === 0) page.pageIndex = i + base;
						else page.pageIndex = (i - 1) + base;
						if (page.pageIndex > $scope.totalPages) break;
						page.text = page.pageIndex + "";
						page.active = $scope.pageNow == page.pageIndex;
						$scope.pages.push(page);
					}
				};

				// 是否上一页
				$scope.isFirst = function () {
					return $scope.pageNow <= 1;
				};

				// 首页
				$scope.first = function () {
					$scope.selectPage(1);
				};

				// 上一页
				$scope.prev = function () {
					$scope.selectPage($scope.pageNow - 1);
				};

				// 下一页
				$scope.next = function () {
					$scope.selectPage($scope.pageNow + 1);
				};

				// 是否尾页
				$scope.isLast = function () {
					return $scope.pageNow >= $scope.totalPages;
				};

				// 尾页
				$scope.last = function () {
					$scope.selectPage($scope.totalPages);
				};

				// 编译页面显示模板 ，支持多语言国际化支持
				$scope.getText = function (key) {
					return pagerConfig.text[key];
				};

				// angular 保证双向绑定的安全机制
				var safeApply = function (fn) {
					var phase = $scope.$root.$$phase;
					if (phase == '$apply' || phase == '$digest') {
						if (fn && (typeof (fn) === 'function')) {
							fn();
						}
					} else {
						$scope.$apply(fn);
					}
				};

				// 重置分页
				$scope.resetPage = function () {
					$scope.totalPages = Math.floor(($scope.totalCount + ($scope.pageSize - 1)) / $scope.pageSize);
					recalc();
					buildPageInfo();
				};

				// 分页数据信息
				var buildPageInfo = function () {
					var startNum = ($scope.pageNow - 1) * $scope.pageSize + 1;
					var endNum = startNum + $scope.pageSize - 1;
					endNum = endNum > $scope.totalCount ? $scope.totalCount : endNum;
					$scope.pageInfo = "共" + $scope.totalPages + "页，第" + $scope.pageNow + "/" + $scope.totalPages + "页，共" + $scope.totalCount + "条数据，第" + startNum + "-" + endNum + "条数据";
				};

				// 编译页面显示
				var buildPages = function (
					pgIndex) {
					buildPageInfo();
					var pageInRange = false;
					for (var i = 0, j = $scope.pages.length; i < j; i++) {
						var page = $scope.pages[i];
						page.active = false;
						if (page.pageIndex == pgIndex) {
							pageInRange = true;
							page.active = true;
						}
					}
					if (!pageInRange) { // 叶范围超出，再重新生成新范围的页
						var rangeInt = Math.floor(pgIndex / $scope.listSize);
						recalc(rangeInt);
					}

				};

				// 核心函数
				$scope.selectPage = function (
					pgIndex) {
					if (pgIndex < 1 || pgIndex > $scope.totalPages) return;
					$scope.pageNow = pgIndex;
					buildPages(pgIndex);
					safeApply(function () {
						if ($scope.onPageChange) {
							$timeout(
								$scope.onPageChange, 100);
						}
					});
				};
			}],
			link: function (scope, element, attrs) {
				scope.$watch("totalCount", scope.resetPage);
			},
			template: '\
			<div class="col-md-6 col-sm-6">\
			     <div class="dataTables_info" role="status" aria-live="polite" data-ng-bind="pageInfo"></div>\
           </div>\
		   <div class="col-md-6 col-sm-6">\
           <div class="dataTables_paginate paging_bootstrap_full_number">\
                <ul class="pagination" style="visibility: visible;">\
                    <li class="prev" data-ng-class="{disabled: isFirst()}">\
	                      <a  href="javascript:void(0);" data-ng-click="first();" title="{{getText(\'first\')}}">\
	                         <i class="fa fa-angle-double-left"></i>\
					      </a>\
                    </li>\
                    <li class="prev" data-ng-class="{disabled: isFirst()}">\
					      <a href="javascript:void(0);" data-ng-click="prev();" title="{{getText(\'prev\')}}">\
					        <i class="fa fa-angle-left"></i>\
					      </a>\
		            </li>\
                    <li data-ng-repeat="page in pages" data-ng-class="{active: page.active}">\
				          <a href="javascript:void(0);" data-ng-click="selectPage(page.pageIndex)">{{page.pageIndex}}</a>\
		            </li>\
			        <li class="next" data-ng-class="{disabled: isLast()}">\
			           <a href="javascript:void(0);" data-ng-click="next();" title="{{getText(\'next\')}}">\
			               <i class="fa fa-angle-right"></i>\
			           </a>\
			        </li>\
                    <li class="next" data-ng-class="{disabled: isLast()}">\
                           <a href="javascript:void(0);" data-ng-click="last();" title="{{getText(\'last\')}}">\
				              <i class="fa fa-angle-double-right"></i>\
				           </a>\
                     </li>\
                  </ul>\
             </div>\
			 </div>'
		};
	}).constant('pagerConfig', {
		text: {
			first: '首页',
			prev: '上一页',
			next: '下一页',
			last: '末页'
		}
	});
});