/* 
* @Author: zhaocaimao
* @Date:   2016-12-25 13:25:45
* @Last Modified by:   zhaocaimao
* @Last Modified time: 2016-12-25 13:36:38
*/

'use strict';
const electron = require('electron');
const { app, BrowserWindow, ipcMain, Menu, dialog, shell } = electron;
const fs = require('fs'), http = require('http'), url = require("url"),
    mkdirp = require('mkdirp'), urllib = require(__dirname + '/assets/lib/urllib'),
    localStorage = require('localStorage'), Node_Xlsx = require("node-xlsx"), Co = require('co'),
    BosClient = require("bce-sdk-js").BosClient, log4js = require('log4js'), validator = require('validator');


/**
 * @see 配置全局变量(系统基础配置)
 */
global.globalObject = {
    'baseConfig': {
        'HTTP': {
            'HTTPFIX': `http://`,
            'HTTPSFIX': `https://`
        },
        'SERVER': {
            'HOST': `www.xunchabing.com`,
            'FIX': `.smk`
        },
        'DOTFIX': `.`,
        'FORMAT': {
            'DATE': {
                'DEFAULT': `yyyy-MM-dd`,
                'DATETIME': `yyyy-MM-dd HH:mm:ss`,
                'FULL': `yyyyMMddHHmmss`,
                'GMT': `yyyy-MM-dd'T'HH:mm:ss'Z'`
            },
            'ENCODING': `UTF-8`
        },
        'BOS': {
            'THUMB': `bj.bcebos.com`
        },
        'API': {
            'FIX': `/api/`,
            'APPKEY': `87511c475f5266e6a8ffe1cf4f28ec82`,
            'SALT': `ymnl1314`,
            'APIKEY': `9125e37e07be05a72e80dab67a7fde4f`
        },
        'LOCALSTORAGE': {
            'UID': `storageUid`,
            'PHONE': `storagePhone`,
            'USERTYPE': `storageUserType`,
            'COOKIEID': `storageCookie`,
            'EMAIL': `storageEmail`,
            'LOGININFO': `storageLoginInfo`
        },
        'HEADERS': {
            'ANGULAR': {
                'Content-Type': `application/json;charset=UTF-8`
            }
        }
    },
    'haveDownLoadStore': false //当前是否存在正在下载的门店信息
};


/**
 * @see 重写date  配置文件，实现自定义格式化时间
 * @param format 需要格式化的格式
 */
Date.prototype.format = function (format) {
    var date = {
        "M+": this.getMonth() + 1,
        "d+": this.getDate(),
        "H+": this.getHours(),
        "m+": this.getMinutes(),
        "s+": this.getSeconds(),
        "q+": Math.floor((this.getMonth() + 3) / 3),
        "S+": this.getMilliseconds()
    };
    if (/(y+)/i.test(format)) {
        format = format.replace(RegExp.$1, (this.getFullYear() + '').substr(4
            - RegExp.$1.length));
    }
    for (var k in date) {
        if (new RegExp("(" + k + ")").test(format)) {
            format = format.replace(RegExp.$1, RegExp.$1.length == 1
                ? date[k]
                : ("00" + date[k]).substr(("" + date[k]).length));
        }
    }
    return format;
}

/**
 * @see 日志文件配置
 */
log4js.configure({
    appenders: {
        xcLogFile: {
            type: 'dateFile',
            filename: `${__dirname}/logs/xunchabing`,//
            alwaysIncludePattern: true,
            pattern: `${global.globalObject.baseConfig.FORMAT.DATE.DEFAULT}.log`,
            maxLogSize: 1024
        },
        xcLogConsole: {
            type: 'console'
        }
    },
    categories: {
        default: {
            appenders: ['xcLogFile'],
            level: 'all'
        },
        xcLogFile: {
            appenders: ['xcLogFile'],
            level: 'all'
        },
        xcLogConsole: {
            appenders: ['xcLogConsole'],
            level: log4js.levels.ALL
        }
    }
});

module.exports = log4js.getLogger('xcLogConsole');
const logger = log4js.getLogger('xunchabing');

/**
 * @see 下载信息
 */
const downLoaduser = {
    'taskurl': {
        'download': `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${global.globalObject.baseConfig.SERVER.HOST}${global.globalObject.baseConfig.API.FIX}clientdownload/getDownLoadTaskUrl${global.globalObject.baseConfig.SERVER.FIX}?apiKey=${global.globalObject.baseConfig.API.APIKEY}`,
        'finish': `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${global.globalObject.baseConfig.SERVER.HOST}${global.globalObject.baseConfig.API.FIX}clientdownload/updateTaskStatus${global.globalObject.baseConfig.SERVER.FIX}?apiKey=${global.globalObject.baseConfig.API.APIKEY}`,
        'getUploadInfo': `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${global.globalObject.baseConfig.SERVER.HOST}${global.globalObject.baseConfig.API.FIX}clientdownload/updateTaskStatus${global.globalObject.baseConfig.SERVER.FIX}?apiKey=${global.globalObject.baseConfig.API.APIKEY}`,
        'uploadSuccess': `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${global.globalObject.baseConfig.SERVER.HOST}${global.globalObject.baseConfig.API.FIX}clientdownload/updateTaskStatus${global.globalObject.baseConfig.SERVER.FIX}?apiKey=${global.globalObject.baseConfig.API.APIKEY}`
    },
    'downLoadUid': '',//登陆者uid
    'downLoadCookieId': '',//登陆者cookidid
    'downloadEmail': '',//登陆者email
    'DOWNLOAD_DIR': `${__dirname}/downloads/`, //下载根目录
    'uploadFileStatus': 'applystorefile/addFile'

}

//需要下载的url
const urlArr = [], responseControllerObj = {};

//自定义菜单模板
let template = [{
    label: '查看',
    submenu: [{
        icon: `${__dirname}/assets/icon/fullscreen.png`,
        label: '切换全屏',
        accelerator: (() => {
            if (process.platform === 'darwin') {
                return 'Ctrl+Command+F';
            } else {
                return 'F11';
            }
        })(),
        click: (item, focusedWindow) => {
            if (focusedWindow) {
                focusedWindow.setFullScreen(!focusedWindow.isFullScreen());
            }
        }
    }, {
        icon: `${__dirname}/assets/icon/tool.png`,
        label: '切换开发者工具',
        accelerator: (() => {
            if (process.platform === 'darwin') {
                return 'Alt+Command+I';
            } else {
                return 'Ctrl+Shift+I';
            }
        })(),
        click: (item, focusedWindow) => {
            if (focusedWindow) {
                focusedWindow.toggleDevTools();
            }
        }
    }]
}, {
    label: '应用',
    role: 'window',
    submenu: [{
        icon: `${__dirname}/assets/icon/minimize.png`,
        label: '最小化窗口',
        accelerator: 'CmdOrCtrl+M',
        role: 'minimize'
    }, {
        icon: `${__dirname}/assets/icon/close.png`,
        label: '关闭应用',
        accelerator: 'CmdOrCtrl+X',
        role: 'close'
    }, {
        type: 'separator'
    }, {
        icon: `${__dirname}/assets/icon/restart.png`,
        label: '重启应用',
        accelerator: 'CmdOrCtrl+Shift+T',
        // enabled: false,
        // key: 'reopenMenuItem',
        click: () => {
            app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
            app.exit(0);
        }
    }]
}, {
    label: '帮助',
    role: 'help',
    submenu: [{
        icon: `${__dirname}/assets/icon/homepage.png`,
        label: '项目主页',
        click: () => {
            shell.openExternal('http://wwww.xunchabing.com');
        }
    }, {
        type: 'separator'
    }, {
        icon: `${__dirname}/assets/icon/email.png`,
        label: '问题反馈',
        click: () => {
            shell.openExternal('mailto:service@shudongyun.com');
        }
    }, {
        icon: `${__dirname}/assets/icon/phone.png`,
        label: '联系我们',
        click: (item, focusedWindow) => {
            if (focusedWindow) {
                const options = {
                    type: 'info',
                    title: `联系我们`,
                    message: `联系我们`,
                    detail: `联系人: 张大勇\n联系电话: 13520095310`
                }
                dialog.showMessageBox(focusedWindow, options, () => {
                })
            }
        }
    }, {
        icon: `${__dirname}/assets/icon/info.png`,
        label: `关于我们`,
        click: (item, focusedWindow) => {
            if (focusedWindow) {
                const options = {
                    type: 'info',
                    title: `${app.getName()}`,
                    message: `${app.getName()}`,
                    //detail: `版本:${app.getVersion()}\nShell:${process.versions.electron}\n呈现器:${process.versions.chrome}\nNode:${process.versions.node}\n版权:数董科技`
                    detail: `巡查兵下载器\n版本号${app.getVersion()}\nCopyright© 2014-2018 All Rights Reserved`
                }
                dialog.showMessageBox(focusedWindow, options, () => {
                })
            }
        }
    }]
}]

//初始化窗口
let mainWindow = null;

/**
 * @see 创建主窗口
 */
function createMainWindow(width, height) {
    //窗口配置
    const options = {
        width: width || 1200,//窗口宽度 默认800
        height: height || 700,//窗口高度 默认600
        title: '数董云项目管理平台客户端',//默认窗口标题
        center: true, //在屏幕中心显示窗口
        icon: __dirname + '/assets/favicon/icon.ico',
        minWidth: 1200,//最下宽度
        minHeight: 700,//最下高度
        titleBarStyle: 'hidden-inset',
        show: false, //所有资源加载完成前隐藏窗口
        backgroundColor: '#2e2c29' //窗口背景色
        //frame: false, //指定false创建无框窗口
        //skipTaskbar: true ,//是否在任务栏中显示窗口
        //resizable: false,  //窗口是否可调整大小
        //maximizable: false, //窗口是否可最大化
        //minimizable: false,//窗口是否可最小化
        //autoHideMenuBar: true, // 自动隐藏菜单栏，除非Alt按下该键
        //transparent: true, //使窗口透明
    }
    const win = new BrowserWindow(options);
    win.loadURL(url.format({
        pathname: `${__dirname}/template/login/login.html`,
        protocol: 'file:',
        slashes: true
    }));//load a local HTML file
    //win.loadURL(`file://${__dirname}/template/login/login.html`); //load a local HTML file
    //win.setMenu(null); //隐藏菜单
    //win.openDevTools();//打开开发工具
    //win.setClosable(false) //设置是否可以由用户手动关闭窗口
    //绑定窗口加载完成准备显示事件
    win.on('ready-to-show', function () {
        mainWindow.maximize();//以最大化状态启动应用
        mainWindow.show();//窗口显示
        mainWindow.focus();//窗口聚焦
    });

    //绑定窗口关闭事件
    win.on('closed', () => {
        mainWindow = null;
        logger.info(`software is close and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
    });
    return win;
}

/**
 * @see 绑定所有窗口关闭事件
 */
app.on('window-all-closed', () => {
    if (process.platform !== 'darwin') {
        logger.info(`software is close and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
        app.quit();
    }
});

/**
 * @see 绑定app  激活事件
 */
app.on('activate', () => {
    if (!mainWindow) {
        mainWindow = createMainWindow();
    }
});


/**
 * @see 绑定app装载完成事件
 */
app.once('ready', () => {
    const { screen } = electron;
    const size = screen.getPrimaryDisplay().workAreaSize, { width, height } = size;
    mainWindow = createMainWindow(width, height);
    const menu = Menu.buildFromTemplate(template);
    Menu.setApplicationMenu(menu);
    logger.info(`software is start and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
});


/**
 * @see 退出账号时判定当前是否存在正在下载的任务
 */
ipcMain.on('hasDownLoadTask', (event) => {
    event.sender.send('hasDownLoadTaskBack', global.globalObject.haveDownLoadStore);
});

/**
 * @see 确认退出账号时触发（用于暂停正在下载的任务）
 */
ipcMain.on('logout', (event) => {
    responseControllerObj[downLoaduser.currDownURL].isPaused = true;
    event.sender.send('logoutBack', 'ok');
});

/**
 * @see 获取项目想在根目录
 */
ipcMain.on('getDownLoadDir', (event) => {
    let downloadDir = downLoaduser.DOWNLOAD_DIR;
    if (process.platform === 'win32')
        downloadDir = `${__dirname}\\downloads\\`;
    event.sender.send('setDownLoadDir', downloadDir);
});

/**
 * @see 登录时同步保存登陆者相关信息
 */
ipcMain.on('saveLoginUserInfo', (event, val) => {
    if (val) {
        localStorage.setItem('mainStoreageUserInfo', JSON.stringify(val));
        event.sender.send('saveLoginUserInfoBack', 'ok');
    }
});


/**
 * @see 下载数据设置相关信息
 */
ipcMain.on('saveDownLoadSettingInfo', (event, val) => {
    if (val) {
        localStorage.setItem('saveDownLoadSettingInfo', JSON.stringify(val));
        event.sender.send('saveDownLoadSettingInfoBack', 'ok');
    }
});


/**
 * @see 主程序绑定文件下载功能
 * @param arg 参数组
 */
var timer = null;
ipcMain.on('fileDownLoad', (event, val) => {
    let { uid, cookieid, email, op } = val;
    if (uid && cookieid && email) {
        //传递下载启动信息给渲染进程
        //event.returnValue = 'pong' 回应同步消息
        if (op) {
            timer = setTimeout(() => {
                if (op === 'only') {
                    event.sender.send('fileDownLoadMessage', `${op}`);
                    op = '';
                    clearTimeout(timer);
                }
            }, 1000);
        }
        downLoaduser.downLoadUid = uid;
        downLoaduser.downLoadCookieId = cookieid;
        downLoaduser.downloadEmail = email;
        //从服务器拉取下载url
        if (!global.globalObject.haveDownLoadStore)
            getDownLoadUrl(event, downLoaduser.taskurl.download);
    }
});

/**
 * @see 从服务器拉取下载数据
 * @param event event
 * @param url 接口URl
 */
var getDownLoadUrl = function (event, url) {
    if (url) {
        var postData = {
            'uid': downLoaduser.downLoadUid,
            'cookieid': downLoaduser.downLoadCookieId
        };
        urllib.POST(url, postData, (err, data) => {
            if (data)
                operationBackData(event, data);
        });
    }
}


/**
 * @see 处理返回数据
 * @param event event
 * @param data 需要处理的返回数据
 */
var operationBackData = function (event, data) {
    let { backdata } = data, { status } = backdata;
    if (status === 0) {
        let fileNum = 0;
        let { applyfileList, fileList, pid, sid, pnum, snum, sname, finalPath } = backdata;
        const param = {
            'pid': pid,
            'sid': sid,
            'pnum': pnum,
            'snum': snum,
            'sname': sname,
            'finalPath': finalPath
        };

        if (applyfileList.length !== 0) {
            for (var m in applyfileList) {
                if (applyfileList[m][7] === 'shudongyun' || applyfileList[m][7].length === 32) {
                    let fileData = {}, fileName = applyfileList[m][6].substr(applyfileList[m][6].lastIndexOf('/') + 1, applyfileList[m][6].length), file = `${downLoaduser.DOWNLOAD_DIR}/${downLoaduser.downloadEmail}/${finalPath}问卷附件/${applyfileList[m][11]}${fileName}`;
                    if (fs.existsSync(file)) {
                        logger.info(`big file exists  is come and fileName is -->${fileName}`);
                        fileNum++;
                    } else {
                        let fileUrl = `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${applyfileList[m][7]}${global.globalObject.baseConfig.DOTFIX}${global.globalObject.baseConfig.BOS.THUMB}/${applyfileList[m][6]}`;
                        fileData['fileUrl'] = fileUrl;
                        fileData['fileType'] = '问卷附件';
                        fileData['fileLabel'] = applyfileList[m][11],
                            fileData['fileName'] = fileName;
                        urlArr.push(fileData);
                    }
                } else {
                    logger.info(`bocuket name error is come and bocuket is -->${applyfileList[m][7]}`);
                    fileNum++;
                }
            }
        }

        if (fileList.length !== 0) {
            for (var n in fileList) {
                if (fileList[n][7] === 'shudongyun' || fileList[n][7].length === 32) {
                    let fileData = {}, isQnumber = 1, originalName = 1, downLoadSettingInfo = localStorage.getItem('saveDownLoadSettingInfo');
                    if (validator.isJSON(downLoadSettingInfo)) {
                        downLoadSettingInfo = JSON.parse(downLoadSettingInfo);
                        isQnumber = downLoadSettingInfo.isQnumber;
                        originalName = downLoadSettingInfo.originalName;
                    }

                    let fileName = fileList[n][6].substr(fileList[n][6].lastIndexOf('/') + 1, fileList[n][6].length);
                    if (originalName === 1)
                        fileName = fileList[n][3];

                    let file = `${downLoaduser.DOWNLOAD_DIR}/${downLoaduser.downloadEmail}/${finalPath}问题附件/`;
                    if (isQnumber === 1)
                        file = `${file}${fileList[n][10]}/`;


                    file = `${file}${fileName}`;

                    if (fs.existsSync(file)) {
                        logger.info(`samll file exists  is come and fileName is -->${fileName}`);
                        fileNum++;
                    } else {
                        let fileUrl = `${global.globalObject.baseConfig.HTTP.HTTPSFIX}${fileList[n][7]}.${global.globalObject.baseConfig.BOS.THUMB}/${fileList[n][6]}`;
                        fileData['fileUrl'] = fileUrl;
                        fileData['fileType'] = '问题附件';
                        if (isQnumber === 1)
                            fileData['fileLabel'] = `${fileList[n][10]}/`;
                        else
                            fileData['fileLabel'] = '';
                        fileData['fileName'] = fileName;
                        urlArr.push(fileData);
                        //urlArr.push(fileUrl);
                    }
                } else {
                    logger.info(`bocuket name error is come and bocuket is -->${fileList[n][7]}`);
                    fileNum++;
                }
            }
        }

        //存在非法URL  或者部分文件已经下载  直接调用接口
        if (fileNum !== 0) {
            const postData = {
                'uid': downLoaduser.downLoadUid,
                'cookieid': downLoaduser.downLoadCookieId,
                'pid': pid,
                'sid': sid,
                'type': 2,
                'fileNum': fileNum
            };
            urllib.POST(downLoaduser.taskurl.finish, postData, (err, data) => {
                if (data) {
                    let { backdata } = data, { status } = backdata;
                    if (status === 0) {
                        //start doewnload
                        if (urlArr.length !== 0) {
                            logger.info(`pnum ---> ${pnum} and snum-- > ${snum} download file is start and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
                            fileDownLoadStart(param, (val) => {
                                fileDownLoadControl(event, val);
                            });
                        } else {
                            logger.info(`pnum is -->${pnum} and snum is -->${snum} error url num is equal total url num!`);
                            downLoaduser.currDownURL = '';
                            global.globalObject.haveDownLoadStore = false;
                            getDownLoadUrl(event, downLoaduser.taskurl.download);
                        }
                    }
                }
            });
        } else {
            //start doewnload
            if (urlArr.length !== 0) {
                logger.info(`pnum ---> ${pnum} and snum-- > ${snum} download file is start and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
                fileDownLoadStart(param, (val) => {
                    fileDownLoadControl(event, val);
                });
            } else { 
                //文件长度为0，变更状态开始
                logger.info(`download file length is 0 need update status is come `)
                const postData = {
                    'uid': downLoaduser.downLoadUid,
                    'cookieid': downLoaduser.downLoadCookieId,
                    'pid': pid,
                    'sid': sid,
                    'type': 2,
                    'fileNum': 0
                };
                urllib.POST(downLoaduser.taskurl.finish, postData, (err, data) => {
                    if (data) {
                        let { backdata } = data, { status } = backdata;
                        if (status === 0) {
                            logger.info(`pnum -->${pnum} and snum --> ${snum} no file is save success!`);
                            downLoaduser.currDownURL = '';
                            global.globalObject.haveDownLoadStore = false;
                            getDownLoadUrl(event, downLoaduser.taskurl.download);
                        } else {
                            app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
                            app.exit(0);
                        }
                    }
                });
                //文件长度为0，变更状态结束
            }
        }
    } else if (status === 3) {
        logger.info(`there is no need to download the data `);
    }
}


/**
 * @see 开始下载
 * @param param 当前下载pid+sid 数据集
 */
var startDownLoad = function (param) {
    if (urlArr.length !== 0) {
        fileDownLoadStart(param, (val) => {
            fileDownLoadControl(event, val);
        });
    }
}

/**
 * @see 开始下载
 * @param param 当前下载pid+sid+pnum+snum 数据集
 */
var fileDownLoadStart = function (param, fn) {
    let { pid, sid, finalPath } = param, file_url = urlArr[0].fileUrl, fileType = urlArr[0].fileType, fileLabel = urlArr[0].fileLabel, fileName = urlArr[0].fileName;
    downLoaduser.currDownURL = file_url;
    responseControllerObj[file_url] = {};

    if (pid && sid && file_url) {
        global.globalObject.haveDownLoadStore = true;
        const options = {
            host: url.parse(encodeURI(file_url)).host,
            port: 80,
            path: url.parse(encodeURI(file_url)).pathname
        };

        let file_name = url.parse(encodeURI(file_url)).pathname.split('/').pop(),
            path = `${downLoaduser.DOWNLOAD_DIR}/${downLoaduser.downloadEmail}/${finalPath}${fileType}/${fileLabel}`;

        if (fileName)
            file_name = fileName;

        file_name = decodeURI(file_name);
        if (!fs.existsSync(path))
            mkdirp.sync(path);

        logger.info(`get file is come and baidu file path is -->${file_url}`);
        let timeout_wrapper = null;
        timeout_wrapper = setTimeout(() => {
            logger.info(`req timeout is come ~~ and current file is -->${file_url}`);
            request.abort();
            request.end();
            app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
            app.exit(0);
        }, 1000 * 60 * 1);


        let totalSize = 0, buffer = [];
        let request = http.get(options, (res) => {
            res.on('data', (data) => {
                //file.write(data);
                buffer.push(data);
                try {
                    totalSize += data.byteLength;
                    //let contentLength = parseInt(res.headers['content-length']);
                    //let process = (totalSize / contentLength) * 100, percent = parseInt(process.toFixed(0));
                    //logger.info(`percent is -->${percent}%`);
                } catch (error) {
                    console.info(`get file res data error is come and error message is  -->${error.message}`);
                }
            }).on('end', () => {
                logger.info(`get file end is come ~~`);
                // clear timeout
                clearTimeout(timeout_wrapper);
                fs.writeFile(`${path}${file_name}`, Buffer.concat(buffer, totalSize), (err) => {
                    if (err) {
                        logger.info(`save file error is come and message is --> ${err.message}`);
                        //no space
                        app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
                        app.exit(0);
                    } else {
                        logger.info(`save file success and save path is --> ${path}${file_name}`);
                        buffer = [];
                        totalSize = 0;
                        if (fn)
                            fn([param]);
                    }
                });
            }).on('error', (err) => {
                // clear timeout
                clearTimeout(timeout_wrapper);
                logger.info(`get file error is come and error message is --> ${err.message} and current url is -->${file_url}`);
                app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
                app.exit(0);
            });
        });


        request.on('error', (e) => {
            logger.info(`get file by url is has error and error is -->${e.message} and current url is --->${file_url}`);
            clearTimeout(timeout_wrapper);
            request.abort();
            request.end();
            app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
            app.exit(0);
            // buffer = [];
            // totalSize = 0;
            // if (fn)
            //   fn([param]);
        });
    };
}
// var fileDownLoadStart = function (param, fn) {
//     let { pid, sid, pnum, snum, sname, finalPath } = param, file_url = urlArr[0].fileUrl, fileType = urlArr[0].fileType, fileLabel = urlArr[0].fileLabel, fileName = urlArr[0].fileName;
//     downLoaduser.currDownURL = file_url;
//     responseControllerObj[file_url] = {};
//     const responseCtrlObj = responseControllerObj[file_url];
//     if (pid && sid && file_url) {
//         global.globalObject.haveDownLoadStore = true;
//         const options = {
//             host: url.parse(encodeURI(file_url)).host,
//             port: 80,
//             path: url.parse(encodeURI(file_url)).pathname
//         };

//         let file_name = url.parse(encodeURI(file_url)).pathname.split('/').pop(),
//             path = `${downLoaduser.DOWNLOAD_DIR}/${downLoaduser.downloadEmail}/${finalPath}${fileType}/${fileLabel}`;

//         if (fileName)
//             file_name = fileName;


//         file_name = decodeURI(file_name);
//         if (!fs.existsSync(path))
//             mkdirp.sync(path);

//         logger.info(`get file is come and baidu file path is -->${file_url}`);
//         let file = fs.createWriteStream(`${path}${file_name}`), totalSize = 0, buffer = [];
//         // let totalSize = 0, buffer = [];
//         let req = http.get(file_url, function (res) {
//             //const { statusCode } = res;
//             res.on('data', (data) => {
//                 //logger.info(`statusCode is -->${statusCode}`);
//                 file.write(data);
//                 // buffer.push(data);
//                 try {
//                     totalSize += data.byteLength;
//                     //let contentLength = parseInt(res.headers['content-length']);
//                     //let process = (totalSize / contentLength) * 100, percent = parseInt(process.toFixed(0));
//                     //logger.info(`percent is -->${percent}%`);
//                 } catch (error) {
//                     console.info(`get file res data error is come and error message is  -->${error.message}`);
//                 }
//                 //if (fn)
//                 //fn([param, totalSize]);

//                 //暂停逻辑
//                 //var isPause = responseCtrlObj['isPaused'] || false;
//                 //if (isPause) {
//                 //res.pause();
//                 // var tt = setInterval(function () {
//                 //var _isPause = obj['isPaused'] || false;
//                 //if (!_isPause) {
//                 // res.resume();
//                 // clearInterval(tt);
//                 //}
//                 //}, 100);
//                 //}
//             }).on('end', () => {
//                 logger.info(`get file end is come ~~`);
//                 file.end();
//                 // try {
//                 //     fs.writeFileSync(`${path}${file_name}`, Buffer.concat(buffer, totalSize));
//                 //     logger.info(`save file success and save path is --> ${path}${file_name}`);
//                 // } catch (e) {
//                 //     logger.info(`save file error is come and message is --> ${e.message}`);
//                 // }

//                 setTimeout(function () {
//                     buffer = [];
//                     totalSize = 0;
//                     if (fn)
//                         fn([param]);
//                 }, 1000);


//             }).on('error', function (err) {
//                 logger.info(`get file error is come and error message is --> ${err.message}`);
//                 //file.end();
//                 // try {
//                 //     fs.writeFileSync(`${path}${file_name}`, Buffer.concat(buffer, totalSize));
//                 //     logger.info(`save file success and save path is --> ${path}${file_name}`);
//                 // } catch (e) {
//                 //     logger.info(`save file error is come and message is --> ${e.message}`);
//                 // }
//                 setTimeout(function () {
//                     buffer = [];
//                     totalSize = 0;
//                     if (fn)
//                         fn([param]);
//                 }, 1000);
//             });
//         }).on('error', (e) => {
//             console.error(`get file by url is has error and error is -->${e.message}`);
//             req.abort();
//             req.end();
//             setTimeout(function () {
//                 buffer = [];
//                 totalSize = 0;
//                 if (fn)
//                     fn([param]);
//             }, 1000);
//         });


//         req.setTimeout(1000 * 60 * 5, function () {
//             logger.info(`req timeout is come ~~ and current file is -->${finalPath}${fileType}/${fileLabel}/${file_name}`);
//             req.abort();
//             req.end();
//             setTimeout(function () {
//                 app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
//                 app.exit(0);
//                 // buffer = [];
//                 // totalSize = 0;
//                 // if (fn)
//                 // fn([param]);
//             }, 1000);
//         });
//     }
// }


/**
 * @see 下载逻辑控制
 * @param val  下载pid + sid + totalSize  数据集
 */
var fileDownLoadControl = function (event, val) {
    logger.info(`fileDownLoadControl is come and val is ${JSON.stringify(val)}`);
    if (val) {
        if (val.length === 1) {
            urlArr.splice(0, 1);
            var postData = {
                'uid': downLoaduser.downLoadUid,
                'cookieid': downLoaduser.downLoadCookieId,
                'pid': val[0].pid,
                'sid': val[0].sid,
                'type': 1
            };

            if (urlArr.length === 0)
                postData.fileNum = 999;

            urllib.POST(downLoaduser.taskurl.finish, postData, (err, data) => {
                logger.info(`api updateTaskStatus  return is come`);
                logger.info(`api updateTaskStatus  return is come ${JSON.stringify(data)}`);
                if (data) {
                    let { backdata } = data, { status } = backdata;
                    if (status === 0) {
                        if (urlArr.length === 0) {
                            logger.info(`pnum -->${val[0].pnum} and snum --> ${val[0].snum} all file is download success and  url  is  -->${downLoaduser.currDownURL}`);
                            logger.info(`pnum ---> ${val[0].pnum} and snum-- > ${val[0].snum} download file is end and nowtime is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
                            downLoaduser.currDownURL = '';
                            global.globalObject.haveDownLoadStore = false;
                            getDownLoadUrl(event, downLoaduser.taskurl.download);
                        } else {
                            logger.info(`pnum -->${val[0].pnum} and snum --> ${val[0].snum} file is downlaod success and  url  is  -->${downLoaduser.currDownURL}`);
                            fileDownLoadStart(val[0], (val) => {
                                logger.info(`fileDownLoadStart is come and val is ${JSON.stringify(val)}`);
                                fileDownLoadControl(event, val);
                            });
                        }
                    } else {
                        logger.info(`download file remote save data to sever is error ~~`);
                    }
                } else {
                    logger.info(`api updateTaskStatus rretrun is error and error is -->${err}`);
                    app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
                    app.exit(0);
                }
            });
        }
    }
}


/**
 * @since 应用重启
 */
ipcMain.on('restart', function (event, data) {
    logger.info(`restart is come and currenttime  is -->${new Date().format('yyyy-MM-dd HH:mm:ss')}`);
    app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
    app.exit(0);
});


let child = null;
ipcMain.on("show-about", () => {
    child = new BrowserWindow({
        parent: mainWindow,
        modal: true,
        show: true,
        title: "test window",
        resizable: false,
        maximizable: false,
        minimizable: false
    });
    child.setMenu(null);
    child.loadURL(`file://${__dirname}/template/login/login1.html`);
});


/**
 * @see  获取每次文件上传的本地路径
 */
var getUpLoadUrl = function (items, num) {
    num++;
    logger.log(items[num]);
    if (items[num] && typeof items[num] != 'undefiend') {
        Co(function* () {
            let config = {
                credentials: {
                    ak: '1195e936172b4376a41877a2d5cbaee3',       //您的AK
                    sk: '893eedda2d7a422cbce9acb8fe360de6'        //您的SK
                }
            };
            let client = new BosClient(config);
            let fileIfHave = fs.existsSync(items[num]);
            console.log(items[num]);
            console.log(fileIfHave);
            if (fileIfHave) {
                let fileInfo = fs.readFileSync(items[num], "binary");
                logger.log(fileInfo);
            }

            let result = yield client.putObjectFromFile('testshudongyun', '1.jpg', items[num]).then(function done(response) {
                // 上传完成
                logger.log('success');
                // console.log(response);
                noticeService(items[num]);
            }).catch(function fail(fail) {
                // 上传失败
                logger.log('fail');
                noticeService(items[num]);
            });
            getUpLoadUrl(items, num);
        }).catch(function (err) {
            logger.log(err);
        });
    } else {
        logger.log('上传完毕');
    }
}


/**
 * @see  上传成功告诉服务器
 */
var noticeService = function (item) {
    let params = {
        'originalName': '',
        'bocuketName': '',
        'cid': '',
        'fileSize': ''
    };
    if (item && item[3]) {
        //小附件
        params["types"] = '';
        params["surveyId"] = '';
        params["rid"] = '';
        params["qid"] = '';
        params["fileval"] = '';

    } else {
        //大附件
        params["aid"] = '';
        params["filePath"] = '';
        params["sourceType"] = '';
    }

    urllib.POST(downLoaduser.uploadFileStatus, {}, (err, data) => {
        //console.log('上传并且通知服务器完毕');
        // if (data.backdata.status === 0) {
        //     getUpLoadUrl();
        // }
    });
}

/**
 *  监听页面开始上传  接收到excel路径  并且执行上传
 */
ipcMain.on('startUpfile', (event, arg) => {
    let items = arg;
    logger.log(items);
    logger.log(typeof items);
    items = 'D:\\gj\\1.jpg';
    let arr = [];
    arr.push(items);
    logger.log(arr);
    getUpLoadUrl(arr, -1);
});
